clear all
close all
clc

%compute mean-min ratio

%% load data
addpath('Z:\Uni\Het Agents\SIPP\Frictional Wage Dispersion\Stata')
M = csvread('fwd_final.out');

names = {'ID' 'Time' 'Wage' 'Residual' 'Weight' 'Age' 'Married' 'Disabled' 'Educ' 'Race' 'Female' 'State' 'Kids' 'Job_occ' 'Labor_e'};

trim = 0; %shall we trim the data

%% drop years with few observation

M(M(:,16)==1992,:) = []; %delete few observations from 1992
M(M(:,16)==2000,:) = []; %delete few observations from 2000

M(:,16)= [];

[~,~,reorder] = unique(M(:,2));
M(:,2) = reorder;
%% Mm using residuals

wage.mean = sum(M(:,4).*M(:,5))./(sum(M(:,5)));
wage.min = min(M(:,4));
wage.first = wprctile(M(:,4),1,M(:,5)); 
wage.fifth = wprctile(M(:,4),5,M(:,5)); 
wage.tenth = wprctile(M(:,4),10,M(:,5)); 

wage.gini = ginicoeff(sort(exp(M(:,4)))); 
wage.var = var(M(:,4)); 

Mm.min = wage.mean/wage.min;
Mm.first = wage.mean/wage.first;
Mm.fifth = wage.mean/wage.fifth;
Mm.tenth = wage.mean/wage.tenth;

%% Mm by age groups

Mm.age = zeros(15,1);

cohort = zeros(15,1);

for i = 1:length(cohort)
    h = i*100/(length(cohort)+1);
    cohort(i,1) = wprctile(M(:,6),h,M(:,5));
end

index = M(:,6)<=cohort(1,1);
wage.mean = sum(M(logical(index),4).*M(logical(index),5))./(sum(M(logical(index),5)));
wage.fifth = wprctile(M(logical(index),4),5,M(logical(index),5));
Mm.age(1,1) = wage.mean/wage.fifth;
for i = 2:length(cohort)
    index = (M(:,6)>cohort(i-1,1)).*(M(:,6)<=cohort(i,1));
    wage.mean = sum(M(logical(index),4).*M(logical(index),5))./(sum(M(logical(index),5)));
    wage.fifth = wprctile(M(logical(index),4),5,M(logical(index),5));
    Mm.age(i,1) = wage.mean/wage.fifth;
end

%% Mm using the Hornstein estimator
H = M;

%keep only those with at least 10 observations
cut = 10;
delete = count_obs(H(:,1));
delete = delete>cut;
H(delete==0,:) = [];   

%create new id without missing values
H = [H zeros(length(H),1)];
H(2:end,16) = diff(H(:,1)); %find position where new agent starts
H(H(:,16)>0,16) = 1; %make it a 1 indicator
H(1,16) = 1;
H(:,1) = cumsum(H(:,16)); %new id
H(:,16) = [];

[Hornstein,mean_R2,perc,std_indi,profile_age_fe,profile2] = horn_regress(H,H(:,1),H(:,2),trim);




%% Graphics and Tables

%Table 2
Mm.first
Mm.fifth
Mm.tenth

Mm.age(1,1)
Mm.age(7,1)
Mm.age(14,1)

wage.var
wage.gini


life = (min(M(:,6)):max(M(:,6)))';


%Figure 4
addpath('Z:\Uni\Het Agents\SIPP\Frictional Wage Dispersion\Model full')

%Mm over life
load('Mm_age_theory.mat','Mm_age_theory');
figure(1)
plot(cohort(2:end),Mm.age(2:end)-Mm.age(2,1),'LineWidth',2.5)
hold on
plot(cohort(2:end),Mm_age_theory(2:end)-Mm_age_theory(2,1),'LineWidth',2.5,'color',[1 0 0])
hold off
h = legend('Data','Theory');
set(h,'Location','SouthWest')
axis tight
ylabel('Mm(age)-Mm(25)','fontsize',13,'FontWeight','bold')
xlabel('Age','fontsize',13,'FontWeight','bold')

