function [Hornstein,mean_R2,perc,std_indi,profile,profile2] = horn_regress(H,ID,period,trim)

%the file executes the Hornstein et al. (2007) estimator and computes
%several statistics of inequality

T = max(period); %maximum number of periods
N = max(ID); %number of agents
resid = -1000*ones(N,T);
age = -1000*ones(N,T);
weight = -1000*ones(N,T);
R2 = zeros(T,1); 
for t = 1:T 
    obs = sum(H(:,2)==t); 
    Ht = H(H(:,2)==t,:);
    %possible that some dummies have only zeros
    Xt = build_X(Ht);
    Yt = H(H(:,2)==t,3);
    reg = ols(Yt,Xt);
    resid1 = zeros(obs,2);
    resid1(:,1) = reg.resid;
    resid1(:,2) = H(H(:,2)==t,1); %corresponding ids
    R2(t,1) = reg.rsqr;
    
    resid(Ht(:,1),t) = resid1(:,1);
    age(Ht(:,1),t) = Ht(:,6);
    weight(Ht(:,1),t) = Ht(:,5);
end

mean_R2 = sum(R2)/length(R2);
% calculate mean residual of agent i
n_obs = sum((resid~=-1000),2); %number of observations of each agent
mean_resid = zeros(N,1);
for i = 1:N
    mean_resid(i,1) = sum(resid(i,:).*(resid(i,:)~=-1000),2)./(n_obs(i,1));
end
aux = (resid~=-1000); %find entries where observations are made 
mean_resid_m = zeros(N,T); %matrix of mean residuals
for t = 1:T
    mean_resid_m(:,t) = mean_resid.*aux(:,t);
end

% calculate wage dispersion 
dispersion = zeros(numel(resid),2);
age = reshape(age,numel(resid),1);
weight = reshape(weight,numel(resid),1);
dispersion(:,1) = reshape(resid,numel(resid),1); %residuals
dispersion(:,2) = reshape(mean_resid_m,numel(mean_resid_m),1); %mean residuals
dispersion(dispersion(:,1)==-1000,:) = []; %delete missing observations
age(age(:,1)==-1000,:) = [];
weight(weight(:,1)==-1000,:) = [];
profile2 = [exp(dispersion(:,1)) age weight]; %residuals without fe
std_indi = std(dispersion(:,2));
log_dispersion = dispersion(:,1)-dispersion(:,2);
log_dispersion = sort(log_dispersion);
dispersion = exp(dispersion(:,1)-dispersion(:,2)); %calculate residual wage dispersion
profile = [dispersion age weight];
dispersion = sort(dispersion);
min_wage_disperse = dispersion(1,1);
min_wage_disperse1 = prctile(dispersion(:,1),1);
min_wage_disperse5 = prctile(dispersion(:,1),5);
min_wage_disperse10 = prctile(dispersion(:,1),10);
mean_wage = sum(dispersion,1)/length(dispersion);
mean_wage1 = sum(dispersion(dispersion>prctile(dispersion(:,1),1),1),1)/sum(dispersion>prctile(dispersion(:,1),1));
mean_wage5 = sum(dispersion(dispersion>prctile(dispersion(:,1),5),1),1)/sum(dispersion>prctile(dispersion(:,1),5));
mean_wage10 = sum(dispersion(dispersion>prctile(dispersion(:,1),10),1),1)/sum(dispersion>prctile(dispersion(:,1),10));
Hornstein.Mm = mean_wage./min_wage_disperse;
Hornstein.Mm1 = mean_wage1./min_wage_disperse1;
Hornstein.Mm5 = mean_wage5./min_wage_disperse5;
Hornstein.Mm10 = mean_wage10./min_wage_disperse10;
% Hornstein = [Hornstein_Mm Hornstein_Mm1 Hornstein_Mm5 Hornstein_Mm10]';

%trim distribution
if trim == 1
    trim_up = prctile(log_dispersion,99.5);
    trim_low = prctile(log_dispersion,0.5);
    indicator_trim = (log_dispersion>trim_up)+(log_dispersion<trim_low);
    log_dispersion(indicator_trim==1,:) = [];
    trim_up = prctile(dispersion,99.5);
    trim_low = prctile(dispersion,0.5);
    indicator_trim = (dispersion>trim_up)+(dispersion<trim_low);
    dispersion(indicator_trim==1,:) = [];
end

perc = zeros(18,1);
for i = 1:18
    perc(i,1) = prctile(dispersion(:,1),10+(i-1)*5);
end
Hornstein.var_log_disp = var(log_dispersion);

Hornstein.gini = ginicoeff(dispersion); 


end