function jtj = jobtojob(M,names)
%computes statistics for wage growth between jobs

%create new column with wage last month (used later)
M = [M zeros(length(M),1)]; 
M(2:end,31) = M(1:end-1,15);
names{1,31} = 'Wage t-1';

M = [M zeros(length(M),1)]; 
M(2:end,32) = M(1:end-1,20);
names{1,32} = 'Tenure t-1';

%compute avergae wage gain
jtj.sample = M(M(:,26)==1,:);
jtj.obs_sample = length(jtj.sample);
jtj.ave = (sum((jtj.sample(:,29)).*(jtj.sample(:,5))))./sum(jtj.sample(:,5));

%compute number of workers incurring wage loss
jtj_loss = jtj.sample(jtj.sample(:,29)<0,:);

jtj.share_loss = sum(jtj_loss(:,5))/sum(jtj.sample(:,5)); 

% compute conditional wage changes
jtj.ave_gain = (sum((jtj.sample(:,29)).*(jtj.sample(:,5)).*(jtj.sample(:,29)>0)))./sum((jtj.sample(:,5)).*(jtj.sample(:,29)>0));

jtj.ave_loss = (sum((jtj.sample(:,29)).*(jtj.sample(:,5)).*(jtj.sample(:,29)<0)))./sum((jtj.sample(:,5)).*(jtj.sample(:,29)<0));

%drop work related benefits
D = M;
aux = jtj.sample;
aux(aux(:,18)==1,:) = []; %drop where new employer is union member but old is not
aux_loss = aux(aux(:,29)<0,:);
jtj.share_loss_U = sum(aux_loss(:,5))/sum(aux(:,5)); 
jtj.ave_loss_U = sum((aux_loss(:,29)).*(aux_loss(:,5)))./sum(aux_loss(:,5));
aux(aux(:,21)==1,:) = []; %drop where new employer pays health but old is not
aux_loss = aux(aux(:,29)<0,:);
jtj.share_loss_U_H = sum(aux_loss(:,5))/sum(aux(:,5)); 
jtj.ave_loss_U_H = sum((aux_loss(:,29)).*(aux_loss(:,5)))./sum(aux_loss(:,5));
aux(aux(:,22)==1,:) = []; %drop where new employer pays educ but old is not
aux_loss = aux(aux(:,29)<0,:);
jtj.share_loss_U_H_E = sum(aux_loss(:,5))/sum(aux(:,5));
jtj.ave_loss_U_H_E = sum((aux_loss(:,29)).*(aux_loss(:,5)))./sum(aux_loss(:,5));

%stratefy by year
for i=min(M(:,3)):max(M(:,3))
    aux_loss = eval(['jtj_loss(:,3)==' int2str(i)]);
    aux_all = eval(['jtj.sample(:,3)==' int2str(i)]);
    eval(['jtj.share_loss_' int2str(i) '=sum((jtj_loss(:,5)).*(aux_loss))/sum((jtj.sample(:,5)).*(aux_all));'])
    eval(['jtj.obs_' int2str(i) '=sum(aux_all);'])
    eval(['jtj.ave_loss_' int2str(i) '=sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(aux_loss))/sum((jtj_loss(:,5)).*(aux_loss));'])
end

%stratefy by sex
jtj.share_loss_male = sum((jtj_loss(:,5)).*(jtj_loss(:,7)==0))/sum((jtj.sample(:,5)).*(jtj.sample(:,7)==0));
jtj.obs_male = sum(jtj.sample(:,7)==0);
jtj.ave_loss_male = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,7)==0)))./sum((jtj_loss(:,5)).*(jtj_loss(:,7)==0));
jtj.share_loss_female = sum((jtj_loss(:,5)).*(jtj_loss(:,7)==1))/sum((jtj.sample(:,5)).*(jtj.sample(:,7)==1));
jtj.obs_female = sum(jtj.sample(:,7)==1);
jtj.ave_loss_female = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,7)==1)))./sum((jtj_loss(:,5)).*(jtj_loss(:,7)==1));

age = zeros(2,1);
for i = 1:length(age)
    h = i*100/(length(age)+1); 
    age(i,1) = prctile(M(:,6),h);
end

%stratefy by age
jtj.share_loss_young = sum((jtj_loss(:,5)).*(jtj_loss(:,6)<=age(1,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,6)<=age(1,1)));
jtj.obs_young = sum(jtj.sample(:,6)<=age(1,1));
jtj.ave_loss_young = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,6)<=age(1,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,6)<=age(1,1)));
jtj.share_loss_middle = sum((jtj_loss(:,5)).*(jtj_loss(:,6)>age(1,1)).*(jtj_loss(:,6)<=age(2,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,6)>age(1,1)).*(jtj.sample(:,6)<=age(2,1)));
jtj.obs_middle = sum((jtj.sample(:,6)>age(1,1)).*(jtj.sample(:,6)<=age(2,1)));
jtj.ave_loss_middle = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,6)>age(1,1)).*(jtj_loss(:,6)<=age(2,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,6)>age(1,1)).*(jtj_loss(:,6)<=age(2,1)));
jtj.share_loss_old = sum((jtj_loss(:,5)).*(jtj_loss(:,6)>age(2,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,6)>age(2,1)));
jtj.obs_old = sum(jtj.sample(:,6)>age(2,1));
jtj.ave_loss_old = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,6)>age(2,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,6)>age(2,1)));

%stratefy by wage (in old job) selection issue
low_25 = wprctile(jtj.sample(:,15),25,jtj.sample(:,5));
top_75 = wprctile(jtj.sample(:,15),75,jtj.sample(:,5));
jtj.share_loss_low_old = sum((jtj_loss(:,5)).*(jtj_loss(:,31)<=low_25))/sum((jtj.sample(:,5)).*(jtj.sample(:,31)<=low_25));
jtj.obs_low_old = sum(jtj.sample(:,31)<=low_25);
jtj.ave_loss_low_old = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,31)<=low_25)))./sum((jtj_loss(:,5)).*(jtj_loss(:,31)<=low_25));
jtj.share_loss_medium_old = sum((jtj_loss(:,5)).*(jtj_loss(:,31)>low_25).*(jtj_loss(:,31)<top_75))/sum((jtj.sample(:,5)).*(jtj.sample(:,31)>low_25).*(jtj.sample(:,31)<top_75));
jtj.obs_low_medium_old = sum((jtj.sample(:,31)>low_25).*(jtj.sample(:,31)<top_75));
jtj.ave_loss_medium_old = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,31)<top_75).*(jtj_loss(:,31)>low_25)))./sum((jtj_loss(:,5)).*(jtj_loss(:,31)<top_75).*(jtj_loss(:,31)>low_25));
jtj.share_loss_high_old = sum((jtj_loss(:,5)).*(jtj_loss(:,31)>=top_75))/sum((jtj.sample(:,5)).*(jtj.sample(:,31)>=top_75));
jtj.obs_high_old = sum(jtj.sample(:,31)>=top_75);
jtj.ave_loss_high_old = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,31)>=top_75)))./sum((jtj_loss(:,5)).*(jtj_loss(:,31)>=top_75));

%stratefy by industry (in new job) selection issue
jtj.share_loss_agriculture = sum((jtj_loss(:,5)).*(jtj_loss(:,14)==1))/sum((jtj.sample(:,5)).*(jtj.sample(:,14)==1));
jtj.obs_agriculture = sum((jtj.sample(:,14)==1));
jtj.share_loss_manufac = sum((jtj_loss(:,5)).*(jtj_loss(:,14)<=8).*(jtj_loss(:,14)>1))/sum((jtj.sample(:,5)).*(jtj.sample(:,14)<=8).*(jtj.sample(:,14)>1));
jtj.obs_manufac = sum((jtj.sample(:,14)<=8).*(jtj.sample(:,14)>1));
jtj.share_loss_trade = sum((jtj_loss(:,5)).*(jtj_loss(:,14)>8).*(jtj_loss(:,14)<=11))/sum((jtj.sample(:,5)).*(jtj.sample(:,14)>8).*(jtj.sample(:,14)<=11));
jtj.obs_trade = sum((jtj.sample(:,14)>8).*(jtj.sample(:,14)<=11));
jtj.share_loss_services = sum((jtj_loss(:,5)).*(jtj_loss(:,14)>11).*(jtj_loss(:,14)<=15))/sum((jtj.sample(:,5)).*(jtj.sample(:,14)>11).*(jtj.sample(:,14)<=15));
jtj.obs_services = sum((jtj.sample(:,14)>11).*(jtj.sample(:,14)<=15));
jtj.share_loss_gov = sum((jtj_loss(:,5)).*(jtj_loss(:,14)>15))/sum((jtj.sample(:,5)).*(jtj.sample(:,14)>15));
jtj.obs_gov = sum(jtj.sample(:,14)>15);

%stratify by tenure
tenure = [5 11 35 119]'; 

jtj.share_loss_T0 = sum((jtj_loss(:,5)).*(jtj_loss(:,32)<=tenure(1,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,32)<=tenure(1,1)));
jtj.obs_T0 = sum(jtj.sample(:,32)<=tenure(1,1));
jtj.ave_loss_T0 = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,32)<=tenure(1,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,32)<=tenure(1,1)));
jtj.share_loss_T6 = sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(1,1)).*(jtj_loss(:,32)<=tenure(2,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,32)>tenure(1,1)).*(jtj.sample(:,32)<=tenure(2,1)));
jtj.obs_T6 = sum((jtj.sample(:,32)>tenure(1,1)).*(jtj.sample(:,32)<=tenure(2,1)));
jtj.ave_loss_T6 = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(1,1)).*(jtj_loss(:,32)<=tenure(2,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(1,1)).*(jtj_loss(:,32)<=tenure(2,1)));
jtj.share_loss_T12 = sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(2,1)).*(jtj_loss(:,32)<=tenure(3,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,32)>tenure(2,1)).*(jtj.sample(:,32)<=tenure(3,1)));
jtj.obs_T12 = sum((jtj.sample(:,32)>tenure(2,1)).*(jtj.sample(:,32)<=tenure(3,1)));
jtj.ave_loss_T12 = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(2,1)).*(jtj_loss(:,32)<=tenure(3,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(2,1)).*(jtj_loss(:,32)<=tenure(3,1)));
jtj.share_loss_T36 = sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(3,1)).*(jtj_loss(:,32)<=tenure(4,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,32)>tenure(3,1)).*(jtj.sample(:,32)<=tenure(4,1)));
jtj.obs_T36 = sum((jtj.sample(:,32)>tenure(3,1)).*(jtj.sample(:,32)<=tenure(4,1)));
jtj.ave_loss_T36 = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(3,1)).*(jtj_loss(:,32)<=tenure(4,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(3,1)).*(jtj_loss(:,32)<=tenure(4,1)));
jtj.share_loss_T132 = sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(4,1)))/sum((jtj.sample(:,5)).*(jtj.sample(:,32)>tenure(4,1)));
jtj.obs_T132 = sum(jtj.sample(:,32)>tenure(4,1));
jtj.ave_loss_T132 = (sum((jtj_loss(:,29)).*(jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(4,1))))./sum((jtj_loss(:,5)).*(jtj_loss(:,32)>tenure(4,1)));

end