function [prob,probit] = jtj_conditional(M,names)

%probability to switch job again conditional on previous tenure and initial
%wage cut

%indicator whether an observation is last in panel
M = [M zeros(length(M),1)];
M(1:end-1,31) = diff(M(:,1));
M(:,31) = M(:,31)~=0;
names{1,31} = 'last obs';

%find workers that make at any time jtj movement 
fcn = @(x)max(x);
M = [M zeros(length(M),1)]; 
M(:,32) = accumarray_expand(M(:,26),M(:,1),fcn);

%drop workers without jtj movement
M(M(:,32)==0,:) = [];
M(:,32) = []; 

%create new column with tenure last month (used later)
M = [M zeros(length(M),1)]; 
M(2:end,32) = M(1:end-1,20);
names{1,32} = 'Tenure t-1';

%delete observations until first jtj movement
fcn = @(x){cumsum(x)}; 
M = [M zeros(length(M),1)];
M(:,33) = accumarray_expand(M(:,26),M(:,1),fcn);
M(M(:,33)==0,:) = [];
M(:,33) = [];

%record whether spell ended with jtj transition
M = [M zeros(length(M),1)];
M(1:end-1,33) = M(2:end,26);
M(:,1) = order_index(M(:,1));
M(2:end,23) = diff(M(:,1));
M(1:end-1,23) = M(2:end,23);
M(M(:,23)==1,33) = 0; 
names{1,33} = 'ended with jtj';

%drop spells that are not due to jtj transition
M(:,30) = order_index(M(:,30));
M = [M zeros(length(M),1)];
M(2:end,34) = diff(M(:,30));
M(M(:,26)==1,34) = 0; %all spells not started by jtj=1
M = [M zeros(length(M),1)];
M(:,35) = accumarray_expand(M(:,34),M(:,30),fcn);
M(M(:,35)==1,:) = [];
M(:,34:35) = [];
M(:,30) = order_index(M(:,30));
names{1,30} = 'jtj spell';

%innitial wage change
fcn = @(x){x(1,1)}; 
M = [M zeros(length(M),1)];
M(:,34) = accumarray_expand(M(:,29),M(:,30),fcn);
names{1,34} = 'initial wage change';

%expand tenure from last job
fcn = @(x){x(1,1)}; 
M(:,32) = accumarray_expand(M(:,32),M(:,30),fcn); 

%probit regression for initial wage change
Y_probit = M(M(:,31)==0,33);
X_probit = M(M(:,31)==0,34);
b = glmfit(X_probit,Y_probit,'binomial','link','probit');
probit.b_wage = b(2,1);
yfit = glmval(b,X_probit,'probit');
probit.schedule = [X_probit yfit];
probit.schedule_wage = sortrows(probit.schedule,1);

%probit regression for previous tenure
Y_probit = M(M(:,31)==0,33); 
X_probit = M(M(:,31)==0,32);
b = glmfit(X_probit,Y_probit,'binomial','link','probit');
probit.b_tenure = b(2,1);
yfit = glmval(b,X_probit,'probit');
probit.schedule = [X_probit yfit];
probit.schedule_tenure = sortrows(probit.schedule,1);

%indicate last month of jtj spell
M = [M zeros(length(M),1)];
M(:,35) = count_obs(M(:,30));
names{1,35} = 'N obs';
M = [M zeros(length(M),1)];
M(2:end,36) = diff(M(:,30));
M(1,36) = 1;
M(:,36) = M(:,36)~=0;
names{1,36} = 'd jtj spell';
M(M(:,36)==1,31) = 0; %set last obs to zero if length of spell is 1


G = M(M(:,34)>=0,:); %all observations where individual had a wage gain
L = M(M(:,34)<0,:); %all observations where individual had a wage loss

prob.EE_G = sum(G(G(:,31)==0,33).*G(G(:,31)==0,5))/sum(G(G(:,31)==0,5)); %EE flow rate for those having a gain
prob.EE_L = sum(L(L(:,31)==0,33).*L(L(:,31)==0,5))/sum(L(L(:,31)==0,5)); %EE flow rate for those having a loss
 
end