clear all
close all
clc

% computes statistics for job to job movements with 3 month smoothed wages
% before and after transition

%% load data
addpath('Z:\Uni\Het Agents\SIPP\Frictional Wage Dispersion\Stata')

M = csvread('flows_final.out');
CPI = csvread('CPI.txt');
CPI = CPI';

names = {'id' 'time' 'year' 'month' 'weight' 'age' 'female' 'metro' 'emp' 'wave' 'multjob' 'job_id' 'occ' 'indu' 'wage' 'hourly?' 'imputed' 'union' 'Reason' 'tenure' 'health' 'educ_pay'};

outliers=1; %delete outliers
deflate = 0; %shall we deflate?
hourly = 0; %use only houerly wages
impute = 1; %drop imputed wages


M(M(:,3)==1992,:) = []; %delete the few observations from 1992
M(M(:,3)==2000,:) = []; %delete the few observations from 2000
%% calculate indicator functions

if hourly %drop employed with non-hourly wages
    M(logical((M(:,16)==0).*(M(:,9)==1)),:) = [];
end

if impute %drop employed with imputed wages
    M(logical((M(:,17)==1).*(M(:,9)==1)),:) = [];
end


%calculate starting point of new agents
M = [M zeros(length(M),1)];
M(2:end,23) = diff(M(:,1));
M(:,23) = M(:,23)~=0; %make it a 1 indicator
M(1,23) = 1;
names{1,23} = 'd indi';

%calculate missing months
M = [M zeros(length(M),1)];
M(2:end,24) = diff(M(:,2));
M(:,24) = M(:,24)~=1;
M(M(:,23)==1,24) = 0; %zero where new agent starts
names{1,24} = 'd M';

%calculate UE movement
M = [M zeros(length(M),1)];
M(2:end,25) = diff(M(:,9));
M(:,25) = M(:,25)==1;
M(M(:,23)==1,25) = 0; %zero where new agent starts
M(M(:,24)==1,25) = 0; %zero where new month starts
names{1,25} = 'd E';

%calculate EE movements
M = [M zeros(length(M),1)];
M(2:end,26) = diff(M(:,12));
M(:,26) = M(:,26)~=0;
M(M(:,23)==1,26) = 0; %zero where new agent starts
M(M(:,24)==1,26) = 0; %zero where month is missing
M(M(:,25)==1,26) = 0; %zero where UE movement takes place
M(M(:,9)==0,26) = 0; %zero where agent is unemployed
names{1,26} = 'd EE'; 


%calculate change in union
M = [M zeros(length(M),1)]; %change in union membership
M(2:end,27) = diff(M(:,18));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,18) = M(:,27)==1;
M(:,27) = [];
names{1,18} = 'd Union';

%calculate change in employer payd health coverage
M = [M zeros(length(M),1)]; %change in payd health insurance
M(2:end,27) = diff(M(:,21));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,21) = M(:,27)==1;
M(:,27) = [];
names{1,21} = 'd Health';

%calculate change in employr payd education
M = [M zeros(length(M),1)]; %change in payd educ
M(2:end,27) = diff(M(:,22));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,22) = M(:,27)==1;
M(:,27) = [];
names{1,22} = 'd Educ_pay';


%drop unemployed and recalculate starting point of new agent
M(M(:,9)==0,:) = []; 
M(2:end,23) = diff(M(:,1)); 
M(:,23) = M(:,23)~=0; %make it a 1 indicator

%new employment spell number
M = [M zeros(length(M),1)];
indicator1 = sum(M(:,23:25)>0,2);
indicator1 = indicator1>0;
M(:,27) = indicator1;
names{1,27} = 'E spell';

prob.EE = sum(M(M(:,27)==0,26).*M(M(:,27)==0,5))/sum(M(M(:,27)==0,5)); %EE flow rate

%calculate by year
for i=min(M(:,3)):max(M(:,3))
    universe = eval(['M(:,3)==' int2str(i)]);
    eval(['prob.EE_' int2str(i) '=sum((universe).*(M(:,5)).*(M(:,27)==0).*(M(:,26)))/sum((universe).*(M(:,5)).*(M(:,27)==0));'])
end


%% wage changes
%add CPI (CPI runs from 1.1992 til 12.2000)
CPI = reshape(CPI,numel(CPI),1);
add = (min(M(:,3))-min(M(:,3)))*12+min(M(M(:,3)==min(M(:,3)),4))-1;
M = [M zeros(length(M),1)];
for t = 1:max(M(:,2))
    M(M(:,2)==t,28) = CPI(t+add,1);
end
M(:,28) = M(:,28)/100;
names{1,28} = 'CPI';

%deflate wages
if deflate == 1
    M(:,15) = M(:,15)./M(:,28);
end

%compute mean wages over 3 month before and after jtj
M = [M zeros(length(M),1)];
M(:,29) = (M(:,23)+M(:,24)+M(:,25)+M(:,26))>0;

M(:,30) = count_obs(M(:,29));
j = find(M(:,26)==1);

for i=1:length(j)
    %length of new spell
    if M(j(i),30) > 2
        M(j(i),15) = mean(M(j(i):j(i)+2,15));
    elseif M(j(i),30) > 1
        M(j(i),15) = mean(M(j(i):j(i)+1,15));
    end
    %length of previous spell
    if M(j(i)-1,30) > 2
        M(j(i)-1,15) = mean(M(j(i)-3:j(i)-1,15));
    elseif M(j(i)-1,30) > 1
        M(j(i)-1,15) = mean(M(j(i)-2:j(i)-1,15));
    end
end
clear j span_spelllength index
M(:,29:30) = [];

%compute wage growth
M = [M zeros(length(M),1)];
M(2:end,29) = diff(log(M(:,15)));
names{1,29} = 'd ln(w)';

%delete outliers
if outliers == 1
    indicator1 = M(:,27);
    spell = indicator1+M(:,26); %add EE movements!!!
    spell = spell~=0;
    M = [M zeros(length(M),1)];
    M(:,30) = cumsum(spell);
    names{1,30} = 'spell number';
    M(indicator1==1,:) = []; %delete missing months, id changes and ue movements
    indicator_out = (M(:,29)>prctile(M(:,29),99.5))+(M(:,29)<prctile(M(:,29),0.5));
    indicator_out = indicator_out~=0;
    spell_aug = cumsum(indicator_out.*(~M(:,26))); 
    M(:,30) = M(:,30)+spell_aug;
    M(indicator_out==1,:) = [];
else
    indicator1 = M(:,27);
    spell = indicator1+M(:,26); %add EE movements!!!
    spell = spell~=0;
    M = [M zeros(length(M),1)];
    M(:,30) = cumsum(spell);
    names{1,30} = 'spell number';
    M(indicator1==1,:) = []; %delete missing months, id changes and ue movements
end

%% Results
jtj = jobtojob(M);

%share of losses and average losses with smooth wages
jtj.share_loss
jtj.ave_loss