clear all
close all
clc

% computes all statistics for job to job movements
%% load data
addpath('Z:\Uni\Het Agents\SIPP\Frictional Wage Dispersion\Stata')

M = csvread('flows_final.out');
CPI = csvread('CPI.txt');
CPI = CPI';

names = {'id' 'time' 'year' 'month' 'weight' 'age' 'female' 'metro' 'emp' 'wave' 'multjob' 'job_id' 'occ' 'indu' 'wage' 'hourly?' 'imputed' 'union' 'Reason' 'tenure' 'health' 'educ_pay'};

outliers=1; %delete outliers
deflate = 0; %shall we deflate?
hourly = 0; %use only houerly wages
impute = 1; %drop imputed wages


M(M(:,3)==1992,:) = []; %delete the few observations from 1992
M(M(:,3)==2000,:) = []; %delete the few observations from 2000
%% calculate indicator functions

if hourly %drop employed with non-hourly wages
    M(logical((M(:,16)==0).*(M(:,9)==1)),:) = [];
end

if impute %drop employed with imputed wages
    M(logical((M(:,17)==1).*(M(:,9)==1)),:) = [];
end

%calculate starting point of new agents
M = [M zeros(length(M),1)];
M(2:end,23) = diff(M(:,1));
M(:,23) = M(:,23)~=0; %make it a 1 indicator
M(1,23) = 1;
names{1,23} = 'd indi';

%calculate missing months
M = [M zeros(length(M),1)];
M(2:end,24) = diff(M(:,2));
M(:,24) = M(:,24)~=1;
M(M(:,23)==1,24) = 0; %zero where new agent starts
names{1,24} = 'd M';

%calculate UE movement
M = [M zeros(length(M),1)];
M(2:end,25) = diff(M(:,9));
M(:,25) = M(:,25)==1;
M(M(:,23)==1,25) = 0; %zero where new agent starts
M(M(:,24)==1,25) = 0; %zero where new month starts
names{1,25} = 'd E';

%calculate EE movements
M = [M zeros(length(M),1)];
M(2:end,26) = diff(M(:,12));
M(:,26) = M(:,26)~=0;
M(M(:,23)==1,26) = 0; %zero where new agent starts
M(M(:,24)==1,26) = 0; %zero where month is missing
M(M(:,25)==1,26) = 0; %zero where UE movement takes place
M(M(:,9)==0,26) = 0; %zero where agent is unemployed
names{1,26} = 'd EE'; 

%% tenure calculations

%calculate tenure
M(:,27) = M(:,26)+M(:,25);
M(M(:,27)~=0,27) = 1;
fcn = @(x){cumsum(x)};
M(:,28) = accumarray_expand(M(:,27),M(:,1),fcn);
M(M(:,9)==0,28) = 0; %job id

M(:,29) = group([M(:,1) M(:,28)]);
M(M(:,9)==0,29) = 0;
fcn = @(x){cumsum(x)};
M(:,30) = accumarray_expand(ones(length(M),1),M(:,29),fcn); %tenure
M(M(:,9)==0,30) = 0;
fcn = @(x){x(1,1)};  
M(:,31) = accumarray_expand(M(:,20),M(:,1),fcn); %tenure at first obs
M = [M zeros(length(M),1)];
M(2:end,32) = diff(M(:,29)); %change in job number
M(1,32) = M(1,9)==1;
M(M(:,32)>0,32) = 1;
M(M(:,32)~=1,32) = 0;
fcn = @(x){cumsum(x)};
M(:,33) = accumarray_expand(M(:,32),M(:,1),fcn); %individual job number
M(M(:,9)==0,33) = 0;
M(:,20) = M(:,30)+(M(:,33)==1).*(max(M(:,31)-1,0));
M(:,27:33) = [];

% compute share of workers entering with zero tenure
share_T0 = sum((M(:,23)==1).*(M(:,9)==1).*(M(:,20)==1))./(sum((M(:,23)==1).*(M(:,9)==1)));

%% continue with indicator functions

%calculate change in union
M = [M zeros(length(M),1)]; %change in union membership
M(2:end,27) = diff(M(:,18));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,18) = M(:,27)==1;
M(:,27) = [];
names{1,18} = 'd Union';

%calculate change in employer payd health coverage
M = [M zeros(length(M),1)]; %change in payd health insurance
M(2:end,27) = diff(M(:,21));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,21) = M(:,27)==1;
M(:,27) = [];
names{1,21} = 'd Health';

%calculate change in employr payd education
M = [M zeros(length(M),1)]; %change in payd educ
M(2:end,27) = diff(M(:,22));
M(M(:,23)==1,27) = 0; %zero where new agent starts
M(M(:,24)==1,27) = 0; %zero where month is missing
M(M(:,25)==1,27) = 0; %zero where UE movement takes place
M(:,22) = M(:,27)==1;
M(:,27) = [];
names{1,22} = 'd Educ_pay';


%drop unemployed and recalculate starting point of new agent
M(M(:,9)==0,:) = []; 
M(2:end,23) = diff(M(:,1)); 
M(:,23) = M(:,23)~=0; %make it a 1 indicator

%new employment spell number
M = [M zeros(length(M),1)];
indicator1 = sum(M(:,23:25)>0,2);
indicator1 = indicator1>0;
M(:,27) = indicator1;
names{1,27} = 'E spell';

prob.EE = sum(M(M(:,27)==0,26).*M(M(:,27)==0,5))/sum(M(M(:,27)==0,5)); %EE flow rate

%calculate by year
for i=min(M(:,3)):max(M(:,3))
    universe = eval(['M(:,3)==' int2str(i)]);
    eval(['prob.EE_' int2str(i) '=sum((universe).*(M(:,5)).*(M(:,27)==0).*(M(:,26)))/sum((universe).*(M(:,5)).*(M(:,27)==0));'])
end

%% wage changes
%add CPI (CPI runs from 1.1992 til 12.2000)
CPI = reshape(CPI,numel(CPI),1);
add = (min(M(:,3))-min(M(:,3)))*12+min(M(M(:,3)==min(M(:,3)),4))-1;
M = [M zeros(length(M),1)];
for t = 1:max(M(:,2))
    M(M(:,2)==t,28) = CPI(t+add,1);
end
M(:,28) = M(:,28)/100;
names{1,28} = 'CPI';

%deflate wages
if deflate == 1
    M(:,15) = M(:,15)./M(:,28);
end

%compute wage growth
M = [M zeros(length(M),1)];
M(2:end,29) = diff(log(M(:,15)));
names{1,29} = 'd ln(w)';


%delete outliers
if outliers == 1
    indicator1 = M(:,27);
    spell = indicator1+M(:,26); %add EE movements!!!
    spell = spell~=0;
    M = [M zeros(length(M),1)];
    M(:,30) = cumsum(spell);
    names{1,30} = 'spell number';
    M(indicator1==1,:) = []; %delete missing months, id changes and ue movements
    indicator_out = (M(:,29)>prctile(M(:,29),99.5))+(M(:,29)<prctile(M(:,29),0.5));
    indicator_out = indicator_out~=0;
    spell_aug = cumsum(indicator_out.*(~M(:,26))); 
    M(:,30) = M(:,30)+spell_aug;
    M(indicator_out==1,:) = [];
else
    indicator1 = M(:,27);
    spell = indicator1+M(:,26); %add EE movements!!!
    spell = spell~=0;
    M = [M zeros(length(M),1)];
    M(:,30) = cumsum(spell);
    names{1,30} = 'spell number';
    M(indicator1==1,:) = []; %delete missing months, id changes and ue movements
end
wage_mean = sum(M(:,15).*M(:,5))./sum(M(:,5));
wage_var = var(M(M(:,26)==1,29),M(M(:,26)==1,15));

%recompute starting point of new agent
M(2:end,23) = diff(M(:,1));
M(:,23) = M(:,23)~=0; %make it a 1 indicator
M(1,23) = 1;

%recompute missing months 
M(2:end,24) = diff(M(:,2));
M(:,24) = M(:,24)~=1;
M(M(:,23)==1,24) = 0; %zero where new agent starts

%% Results

jtj = jobtojob(M,names);
otj = onthejob(M(M(:,26)==0,:));

[prob.EE_con,probit] = jtj_conditional(M,names);

prob.reason = reason(M,names);
names_reson = {'Layoff' 'Retire' 'Childcare' 'Family' 'Own Illness' 'Injury' 'School' 'Fired' 'Bankrupt' 'Employer sold' 'Temporary ended' 'Quit for job' 'Slack work' 'Unsatisfying work conditions' 'Quit for other'};

variance_f = var_following(M,names); %variance at begining of job spell

variance_move = var_move(M,names); %variance and excess variance of job movers

%% compute wage growth conditional on innitial wage change

%spell length
M = [M zeros(length(M),1)];
M(:,31) = count_obs(M(:,30));
names{1,31} = 'Spell length';

long = 0; %count only spells resulting from EE, which are longer than months


if long
    M(M(:,31)<24,:) = [];
else
    M(M(:,31)<2,:) = [];
end

wage_innitial = zeros(max(M(:,30)),1);
wage_gain = zeros(max(M(:,30)),1);
wage_change = zeros(max(M(:,30)),1);
for i = 1:max(M(:,30)) %loop over employment spells
    indicator_EE = sum(M(M(:,30)==i,26)); %did the employment spell start due to EE movement
    if indicator_EE == 1 
        wage_innitial(i,1) = sum(M(M(:,30)==i,29).*M(M(:,30)==i,26)); %innitial wage change after EE
        wage_gain(i,1) = (sum(M(M(:,30)==i,29))-wage_innitial(i,1))./(sum(M(:,30)==i)-1); %wage gain of employment spell after first period
        wage_change(i,1) = (sum(M(M(:,30)==i,29))); %wage change of employment spell
    else %no EE movement took place
        wage_innitial(i,1) = -100000; %will be droped later
        wage_gain(i,1) = -100000;
        wage_change(i,1) = -100000;
    end
end
wage = [wage_innitial wage_gain wage_change];
wage(wage(:,1)== -100000,:) = []; %drop spells without EE movement
jtj.wage = sortrows(wage);

%Figure C1 (1)
figure(1)
plot(jtj.wage(:,1),jtj.wage(:,2))
xlabel('Innitial change in log wages','fontsize',12,'fontweight','bold')
ylabel('Average monthly wage growth after EE','fontsize',12,'fontweight','bold')
axis tight

long = 1; %count only spells resulting from EE, which are longer than months


if long
    M(M(:,31)<24,:) = [];
else
    M(M(:,31)<2,:) = [];
end

wage_innitial = zeros(max(M(:,30)),1);
wage_gain = zeros(max(M(:,30)),1);
wage_change = zeros(max(M(:,30)),1);
for i = 1:max(M(:,30)) %loop over employment spells
    indicator_EE = sum(M(M(:,30)==i,26)); %did the employment spell start due to EE movement
    if indicator_EE == 1 
        wage_innitial(i,1) = sum(M(M(:,30)==i,29).*M(M(:,30)==i,26)); %innitial wage change after EE
        wage_gain(i,1) = (sum(M(M(:,30)==i,29))-wage_innitial(i,1))./(sum(M(:,30)==i)-1); %wage gain of employment spell after first period
        wage_change(i,1) = (sum(M(M(:,30)==i,29))); %wage change of employment spell
    else %no EE movement took place
        wage_innitial(i,1) = -100000; %will be droped later
        wage_gain(i,1) = -100000;
        wage_change(i,1) = -100000;
    end
end
wage = [wage_innitial wage_gain wage_change];
wage(wage(:,1)== -100000,:) = []; %drop spells without EE movement
jtj.wage = sortrows(wage);


%Figure C1 (2)
figure(2)
plot(jtj.wage(:,1),jtj.wage(:,3))
xlabel('Innitial change in log wages','fontsize',12,'fontweight','bold')
ylabel('Total wage change after 2 years','fontsize',12,'fontweight','bold')
axis tight

%% Tables

%Table 2
jtj.share_loss
jtj.ave_loss

jtj.share_loss_U
jtj.ave_loss_U

jtj.share_loss_U_H
jtj.ave_loss_U_H

jtj.share_loss_U_H_E
jtj.ave_loss_U_H_E

jtj.share_loss_low_old
jtj.ave_loss_low_old

jtj.share_loss_medium_old
jtj.ave_loss_medium_old

jtj.share_loss_high_old
jtj.ave_loss_high_old

%Table 7
jtj.ave
jtj.ave_loss

%Table B1 (to obtain the top row, one needs to change the sample in
%EE.do)
wage_mean
prob.EE
wage_var

%Table C1 (to obtain the top panel, one needs to change the sample in
%EE.do. To obtain JTJ1 and JTJ2, one needs to change the id identifier in main_cepr.do)
prob.EE
jtj.share_loss
jtj.ave_loss

%Table C2
%Allstatistics are saved in jtj To obtain the statistics for real wages,
%set "deflate=1" at the top of the file. To obtain them for the subsample of hourly wages, set
%"hourly==1".


%Table 4
variance_move.var_excess
