function statistics = var_move(M,names)

%excess variance of job movers with baseline and three month average wages

[~,~,reorder] = unique(M(:,2));
M(:,2) = reorder;
time_dummy = dummyvar(M(:,2));

jtj = M(M(:,26)==1,:);
otj = M(M(:,26)==0,:);

%regress on constant and time fixed effects
reg = ols(jtj(:,29),[ones(length(jtj),1) time_dummy(M(:,26)==1,2:end)]);
resid.jtj = reg.resid;

reg = ols(otj(:,29),[ones(length(otj),1) time_dummy(M(:,26)==0,2:end)]);
resid.otj = reg.resid;

statistics.var_jtj = var(resid.jtj);
statistics.var_otj = var(resid.otj);
statistics.var_excess = statistics.var_jtj-statistics.var_otj;

%% use half yearly averages
l=3;

M(:,31) = count_obs(M(:,30));
names{1,31} = 'spell length';
E = M(M(:,31)<l*2,:);
M(M(:,31)<l*2,:) = []; %drop short spells 

%sample selection issue 
E = E(E(:,26)==1,:);
F = M(M(:,26)==1,:);

reg = ols(E(:,29),ones(length(E),1));
statistics.var_s_sel = var(reg.resid);

reg = ols(F(:,29),ones(length(F),1));
statistics.var_s_rem = var(reg.resid);

fcn = @(x){cumsum(x)}; 
M(:,32) = accumarray_expand(ones(length(M(:,30)),1),M(:,30),fcn);
names{1,32} = 'number of obs in spell';

%average by half year
for i = 1:(48/l)-2
    M(:,33) = (M(:,31)>=l*2+((i-1)*l)).*(M(:,31)<l*2+i*l);
    M(logical((M(:,33)==1).*(M(:,32)>2*l+((i-1)*l))),:) = [];
    M(:,33) = 0;
end
 
 
%renew spell length
M(:,31) = count_obs(M(:,30)); 
names{1,31} = 'spell length';

%compute half yearly mean wage
for i = 1:(48/l)-1
    M(logical((M(:,32)>=1+(i-1)*l).*(M(:,32)<1+i*l)),33) = i;
end

M(:,33) = group([M(:,30) M(:,33)]); 
names{1,33} = 'new group';

fcn = @(x){mean(x)};
M(:,34) = accumarray_expand(M(:,15),M(:,33),fcn);
names{1,34} = 'mean wage';


%keep only first observation
M = [M zeros(length(M),1)];
M(2:end,35) = diff(M(:,33));
M(1,35) = 1;
M(M(:,35)==0,:) = [];

%wage growth
M(2:end,29) = diff(log(M(:,34)));

%drop change in id
M(:,1) = order_index(M(:,1));
M(2:end,23) = diff(M(:,1));
M(:,23) = M(:,23)~=0; %make it a 1 indicator
M(1,23) = 1;
M(M(:,23)==1,:) = [];

jtj = M(M(:,26)==1,:);
otj = M(M(:,26)==0,:);

%regress on constant 

reg = ols(jtj(:,29),ones(length(jtj),1));
resid.jtj = reg.resid;

reg = ols(otj(:,29),ones(length(otj),1));
resid.otj = reg.resid;

statistics.var_s_jtj = var(resid.jtj);
statistics.var_s_otj = var(resid.otj);
statistics.var_s_excess = statistics.var_s_jtj-statistics.var_s_otj;




end