clear all
close all
clc

%calculates the wage distribution and Lorenz curve in data and model

%% reading in data
addpath('Z:\Uni\Het Agents\SIPP\Frictional Wage Dispersion\Stata')
M = csvread('wage_disp.out');

names = {'id' 'time' 'wage' 'married' 'disable' 'race' 'female' 'kids' 'age'};


addpath('Z:\Frictional Wage Dispersion\Model full')
load('NLSY_SIPP.mat','NLSY_SIPP')
%% routine

trim = 0; %shall we trim the distribution

%% select period


M(M(:,2)~=50,:) = [];  %keep only period 50 (arbitrary)

M(:,3) = M(:,3)*40*4; %monthly wages

trim_up_data = max(M(:,3));
trim_low_data = min(M(:,3));

%% generate residual wages

%generate dummies
race_dummy = dummyvar(M(:,6));
kid_dummy = dummyvar(M(:,8)+1);


Y = log(M(:,3));
X(:,1) = ones(length(Y),1);
X(:,2:3) = M(:,[4:5]);
X(:,4) = M(:,7);
X = [X race_dummy(:,2:end) kid_dummy(:,2:end)];
reg = ols(Y,X);
M(:,3) = exp(reg.resid);

rep = [M(:,9) reg.resid];
rep = sortrows(rep,1);
rep_prof = zeros(max(rep(:,1))-min(rep(:,1))+1,1);
for i = min(rep(:,1)):max(rep(:,1))
    rep_prof(i-min(rep(:,1))+1,1) = var(rep(rep(:,1)==i,2)); 
end


%sort by wage 
M = sortrows(M,3);

%% above continued

%compute Lorenz curve data
M = [M zeros(length(M),1)];
M(:,9) = cumsum(M(:,3)); %cumulative sum of wages
M = [M zeros(length(M),1)];
M(:,10) = M(:,9)./M(end,9); %share to total wage
pop_share_data = [1:length(M)];
pop_share_data = pop_share_data./length(M);

perc_data = zeros(19,1);
for i = 1:19
    perc_data(i,1) = prctile(M(:,3),5+(i-1)*5);
end

%% create wage sample from model and trim data

%drop too old
NLSY_SIPP(NLSY_SIPP(:,8)>33*12,:) = [];

%keep only period 1
NLSY_SIPP = [NLSY_SIPP zeros(length(NLSY_SIPP),1)];
NLSY_SIPP(2:end,9) = diff(NLSY_SIPP(:,7)); 
NLSY_SIPP(1,1) = 1;
NLSY_SIPP(NLSY_SIPP(:,9)~=0,9) = 1;
NLSY_SIPP(NLSY_SIPP(:,9)~=1,:) = []; 

NLSY_SIPP(NLSY_SIPP(:,2)~=1,:) = []; %keep only employed

%group age
for t = 1:33
    index = (NLSY_SIPP(:,8)<= t*12).*(NLSY_SIPP(:,8)> (t-1)*12);
    NLSY_SIPP(logical(index),8) = t;
end


trim_same = 1;
if trim
    if trim_same 
        trim_up = trim_up_data;
        trim_low = trim_low_data;
        indicator_trim = (NLSY_SIPP(:,6)>trim_up)+(NLSY_SIPP(:,6)<trim_low);
        NLSY_SIPP(indicator_trim==1,:) = [];
    else
        trim_up = prctile(NLSY_SIPP(:,6),99);
        trim_low = prctile(NLSY_SIPP(:,6),1);
        indicator_trim = (NLSY_SIPP(:,6)>trim_up)+(NLSY_SIPP(:,6)<trim_low);
        NLSY_SIPP(indicator_trim==1,:) = [];
    end
end

%% compute residual wage

Y = log(NLSY_SIPP(:,6));
X = ones(length(Y),1);
reg_m = ols(Y,X);

rep_mod = [NLSY_SIPP(:,8) reg_m.resid];
rep_mod = sortrows(rep_mod,1);
rep_mod_prof = zeros(max(rep_mod(:,1))-min(rep_mod(:,1))+1,1);
for i = min(rep_mod(:,1)):max(rep_mod(:,1))
    rep_mod_prof(i-min(rep_mod(:,1))+1,1) = var(rep_mod(rep_mod(:,1)==i,2)); 
end

NLSY_SIPP(:,6) = exp(reg_m.resid);

%sort by wage
NLSY_SIPP = sortrows(NLSY_SIPP,6);

%% above continued

%compute Lorenz curve model
NLSY_SIPP = [NLSY_SIPP zeros(length(NLSY_SIPP),1)];
NLSY_SIPP(:,10) = cumsum(NLSY_SIPP(:,6)); %cumulative sum of wages
NLSY_SIPP = [NLSY_SIPP zeros(length(NLSY_SIPP),1)];
NLSY_SIPP(:,11) = NLSY_SIPP(:,10)./NLSY_SIPP(end,10); %share to total wage
pop_share_model = [1:length(NLSY_SIPP)];
pop_share_model = pop_share_model./length(NLSY_SIPP);

perc_model = zeros(19,1);
for i = 1:19
    perc_model(i,1) = prctile(NLSY_SIPP(:,6),5+(i-1)*5);
end

%% wage distribution

%demean
M(:,3) = M(:,3)-mean(M(:,3));

%create bins of wage distribution
n = 500;
wage_grid = linspace(min(M(:,3)),max(M(:,3)),n)';

%find wage position on grid
M = [M zeros(length(M),1)];
for i = 1:length(M)
    M(i,11) = sum(M(i,3)>=wage_grid);
end

%count number of observations per bin
obs = zeros(n,1);
for i = 1:n
    obs(i,1) = sum(M(:,11)==i);
end

%kernel smoother
[predicted, xi] = ksdensity(M(:,3),wage_grid,'kernel','normal','width',0.1); %100 0.02
predicted = predicted/sum(predicted); %normalize to 1

%demean wages
NLSY_SIPP(:,6) = NLSY_SIPP(:,6)-mean(NLSY_SIPP(:,6));

%find wage position on grid
a = zeros(length(NLSY_SIPP),1);
for i = 1:length(NLSY_SIPP)
    a(i,1) = sum(NLSY_SIPP(i,6)>=wage_grid);
end

%count number of observations per bin
obs_m = zeros(n,1);
for i = 1:n
    obs_m(i,1) = sum(a(:,1)==i);
end

%kernel smoother
[predicted_model, xi_model] = ksdensity(NLSY_SIPP(:,6),wage_grid,'kernel','normal','width',0.1);
predicted_model = predicted_model/sum(predicted_model);


%% make graph


%Figure 5
plot(wage_grid,predicted,'k','LineWidth',2.5)
hold on
plot(wage_grid,predicted_model,'r--','LineWidth',2.5)
hold off
xlabel('w','fontsize',13,'FontWeight','bold')
ylabel('Mass of agents','fontsize',13,'FontWeight','bold')
h=legend('Data','Model');
set(h,'fontsize',12)
axis tight

