clear all
close all
clc

% Main file for On the job search

%% parameters
n = 100; %number of grid points for lambda_d
nd = 100000; %grid points for distribution function

rho = 0.4;
lambda_u = 0.3;
lambda_d = linspace(0,0.99,n)';
r = 0.0041;
destruct = 0.03;
EE = 0.025;

sigma = 0.2;
mu = 0;
w_max = 5;

up.l = 0.2; %updating weight
up.b = 0.2;

tol.l = 10^-10;
tol.b = 10^-12;
%% loop over lambda_d

lambda = zeros(n,1);
w_res = zeros(n,1);
w_bar = zeros(n,1);
b = zeros(n,1);
Mm = zeros(n,1);
g = zeros(nd,n,2);

for i = 1:n
    if i == 1
        lambda(i,1) = 0.1; %guss lambda
        b(i,1) = 0.5; %guess unemployment benefits
    else
        lambda(i,1) = lambda(i-1,1);
        b(i,1) = b(i-1,1);
    end
    crit.b = 1;
    while crit.b>tol.b
        
        crit.l = 1;
        while crit.l > tol.l
            %% compute reservation wage
            
            w_res0 = log(b(i,1)); %guess
            ln_solution = fzero(@(x)reservation(exp(x),w_max,b(i,1),lambda(i,1),lambda_u,lambda_d(i,1),destruct,r,mu,sigma),w_res0);
            w_res(i,1) = exp(ln_solution);
            
            
            %% lambda consistent with EE
            lambda0 = log(lambda(i,1)); %guess
            ln_solution = fzero(@(x)find_lambda(exp(x),EE,lambda_d(i,1),w_res(i,1),destruct,mu,sigma),lambda0);
            lambda_new = exp(ln_solution);
            
            crit.l = abs(lambda(i,1)-lambda_new);
            
            lambda(i,1) = (1-up.l)*lambda(i,1)+up.l*lambda_new;
        end
        
        %% mean wage
        wgrid = linspace(w_res(i,1),w_max,nd)';
        w_bar(i,1) = find_wbar(w_res(i,1),wgrid,destruct,lambda(i,1),lambda_d(i,1),sigma,mu);
        b_new = rho*w_bar(i,1);
        
        crit.b = abs(b(i,1)-b_new);
        
        b(i,1) = (1-up.b)*b(i,1)+up.b*b_new;
    end
    %% compute wage cdf
    wgrid = linspace(w_res(i,1),w_max,nd)'; %grid for distribution function
    g(:,i,1) = wgrid;
    g(:,i,2) = distribution(wgrid,w_res(i,1),destruct,lambda(i,1),lambda_d(i,1),mu,sigma);
    
    %% mean min ratio
    Mm(i,1) = w_bar(i,1)/w_res(i,1);
    i
end



%% interpolate wage cdf
wgrid_new = linspace(min(g(1,:,1)),w_max,100000)';
G = zeros(100000,n);

for i = 1:n
     G(:,i) = min(max(interp1_l(g(:,i,1),g(:,i,2),wgrid_new),0),1);
end

%% Graphics
break

%Figure 1
plot(wgrid_new(1:30000),G(1:30000,1),'LineWidth',2.5)
hold on
plot(wgrid_new(1:30000),G(1:30000,20),'LineWidth',2.5,'color',[1 0 0],'LineStyle','--')
hold on
plot(wgrid_new(1:30000),G(1:30000,100),'LineWidth',2.5,'color',[0 1 0],'LineStyle',':')
hold off
axis tight
xlabel('w','fontsize',12)
ylabel('cdf','fontsize',12)

%Figure 2
plot(lambda_d,lambda,'LineWidth',2.5)
axis tight
xlabel('\lambda_d','fontsize',12)
ylabel('\lambda','fontsize',12)


%Figure 3
plot(lambda_d,Mm,'LineWidth',2.5)
axis tight
xlabel('\lambda_d','fontsize',12)
ylabel('Mm','fontsize',12)


%Figure A1
plot(lambda_d,w_res,'LineWidth',2.5)
axis tight
xlabel('\lambda_d','fontsize',12)
ylabel('w*','fontsize',12)


%Figure A2
plot(lambda_d,w_bar,'LineWidth',2.5)
axis tight
xlabel('\lambda_d','fontsize',12)
ylabel('w_{bar}','fontsize',12)

