function Hornstein = Hornstein_SIPP(panel,names)
%computes the Hornstein et al. (2007) estimator and several moments of
%residual inequality

panel(panel(:,2)==2,:) = []; %delete unemployed worker

%keep only those with at least 10 observations
cut = 10;
index = count_obs(panel(:,7));
delete = index>cut;
panel(delete==0,:) = []; 
panel(:,7) = order_index(panel(:,7));

T = max(panel(:,13)); %maximum number of periods
N = max(panel(:,7)); %number of agents

panel(:,6) = log(panel(:,6));

resid = -1000*ones(N,T);
R2 = zeros(T,1); 


for t = 1:T
    obs = sum(panel(:,13)==t); 
    Ht = panel(panel(:,13)==t,:);
    X = ones(obs,1); %regress on a constant
    Y = Ht(:,6);
    reg = ols(Y,X);
    resid1 = zeros(obs,2);
    resid1(:,1) = reg.resid;
    resid1(:,2) = Ht(:,7);%corresponding ids
    R2(t,1) = reg.rsqr;
    resid(resid1(:,2),t) = resid1(:,1);
end

Hornstein.mean_R2 = sum(R2)/length(R2);
% calculate mean residual of agent i
n_obs = sum((resid~=-1000),2); %number of observations of each agent
mean_resid = zeros(N,1);
for i = 1:N
    mean_resid(i,1) = sum(resid(i,:).*(resid(i,:)~=-1000),2)./(n_obs(i,1));
end
aux = (resid~=-1000); %find entries where observations are made 
mean_resid_m = zeros(N,T); %matrix of mean residuals
for t = 1:T
    mean_resid_m(:,t) = mean_resid.*aux(:,t);
end

% calculate wage dispersion
dispersion = zeros(numel(resid),2);
dispersion(:,1) = reshape(resid,numel(resid),1);
dispersion(:,2) = reshape(mean_resid_m,numel(mean_resid_m),1);
dispersion(dispersion(:,1)==-1000,:) = []; %delete missing observations
Hornstein.std_indi = std(dispersion(:,2));
log_dispersion = dispersion(:,1)-dispersion(:,2);
log_dispersion = sort(log_dispersion);
dispersion = exp(dispersion(:,1)-dispersion(:,2)); %calculate residual wage dispersion
dispersion = sort(dispersion);
min_wage_disperse = dispersion(1,1);
min_wage_disperse1 = dispersion(floor(length(dispersion)/100),1);
min_wage_disperse5 = dispersion(floor(length(dispersion)/20),1);
min_wage_disperse10 = dispersion(floor(length(dispersion)/10),1);
mean_wage = sum(dispersion,1)/length(dispersion);
Hornstein.Mm = mean_wage./min_wage_disperse;
Hornstein.Mm1 = mean_wage./min_wage_disperse1;
Hornstein.Mm5 = mean_wage./min_wage_disperse5;
Hornstein.Mm10 = mean_wage./min_wage_disperse10;
Hornstein.perc = zeros(18,1);
for i = 1:18
    Hornstein.perc(i,1) = prctile(dispersion(:,1),10+(i-1)*5);
end
Hornstein.var_log_disp = var(log_dispersion);

Hornstein.gini = ginicoeff(dispersion);
end