function depre = comp_depre(SIPP,names)

%compute reduced form depretiation coefficient

names(1,8) = {'Age'};

SIPP(:,9) = []; %delete experience

%find starting point of new agent
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(2:end,9) = SIPP(2:end,7)-SIPP(1:end-1,7);
SIPP(SIPP(:,9)~=0,9) = 1;
names(1,9) = {'d ID'};

%find EU movement
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(2:end,10) = SIPP(2:end,2)-SIPP(1:end-1,2);
SIPP(SIPP(:,10)==-1,10) = 0;    %set job find to zero
SIPP(SIPP(:,9)==1,10) = 0;     %zero where new agent starts
SIPP(1:end-1,10) = SIPP(2:end,10);
names(1,10) = {'d EU'};

%find UE movement
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(2:end,11) = SIPP(2:end,2)-SIPP(1:end-1,2);
SIPP(SIPP(:,11)==1,11) = 0;    %set job loses to zero (includes artificial initial job loss)
SIPP(SIPP(:,9)==1,11) = 0;     %zero where new agent starts
SIPP(SIPP(:,11)==-1,11) = 1;    %set job findings to one
names(1,11) = {'d UE'};

%% keep only those with EU and then UE movement

%drop obs until eu move (drop households without eu move)
fcn = @(x){cumsum(x)}; 
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,12) = accumarray_expand(SIPP(:,10),SIPP(:,7),fcn);
SIPP(SIPP(:,12)==0,:) = [];
SIPP(:,12) = [];

%recalculate starting point
SIPP(2:end,9) = SIPP(2:end,7)-SIPP(1:end-1,7);
SIPP(SIPP(:,9)~=0,9) = 1;

%drop obs after ue move
fcn = @(x){cumsum(x)};
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,12) = accumarray_expand(SIPP(:,11),SIPP(:,7),fcn);
SIPP(:,12) = accumarray_expand(SIPP(:,12),SIPP(:,7),fcn);
SIPP(SIPP(:,12)>1,:) = [];
SIPP(:,12) = [];

%use only households with eu and ue move
fcn = @(x)max(x);
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,12) = accumarray_expand(SIPP(:,10),SIPP(:,7),fcn);
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,13) = accumarray_expand(SIPP(:,11),SIPP(:,7),fcn);
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,14) = SIPP(:,12)+SIPP(:,13);
SIPP(SIPP(:,14)<2,:) = [];
SIPP(:,12:14) = [];

%% compute unemployment duration and keep only ue observation
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,12) = count_obs(SIPP(:,7));
SIPP(:,12) = SIPP(:,12)-2;
names(1,12) = {'U duration'};

SIPP(SIPP(:,11)==0,:) = [];

%% regression

Y = log(SIPP(:,6));
X = [ones(length(SIPP),1) SIPP(:,12)];

result = ols(Y,X); 
depre = result.beta(2,1);
end