function gain = comp_exp(SIPP,names)

%compute reduced form experience coefficient

%shift job swith indicator one ahead
SIPP = [SIPP zeros(length(SIPP),1)]; 
SIPP(2:end,8) = SIPP(1:end-1,3);
names(1,8) = {'d J'};

%find starting point of new agent
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(2:end,9) = SIPP(2:end,7)-SIPP(1:end-1,7);
SIPP(SIPP(:,9)~=0,9) = 1;
names(1,9) = {'d ID'};


%find UE movement
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(2:end,10) = SIPP(2:end,2)-SIPP(1:end-1,2);
SIPP(SIPP(:,10)==1,10) = 0;    %set job loses to zero (includes artificial initial job loss)
SIPP(SIPP(:,9)==1,10) = 0;     %zero where new agent starts
SIPP(SIPP(:,10)==-1,10) = 1;    %set job findings to one
names(1,10) = {'d UE'};

%compute experience 
SIPP = [SIPP zeros(length(SIPP),1)];
fcn = @(x){cumsum(x)}; 
SIPP(:,11) = accumarray_expand(SIPP(:,2)==1,SIPP(:,7),fcn);
SIPP(:,11) = round(SIPP(:,11)./12);
names(1,11) = {'Exp'};

%keep EE and UE movements
SIPP(((SIPP(:,8)==1)+(SIPP(:,10)==1))==0,:) = []; 

%drop individuals with less than 2 movements
SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,12) = count_obs(SIPP(:,7));
SIPP(SIPP(:,12)<2,:) = [];
SIPP(:,12) = [];

%reorder index
SIPP(:,7) = order_index(SIPP(:,7));

%compute demeaned values
SIPP(:,6) = log(SIPP(:,6));
SIPP = [SIPP zeros(length(SIPP),1)];
fcn = @(x)mean(x);
SIPP(:,12) = accumarray_expand(SIPP(:,6),SIPP(:,7),fcn);
SIPP(:,12) = SIPP(:,12)-SIPP(:,6);
names(1,12) = {'Demeaned log(w)'};

SIPP = [SIPP zeros(length(SIPP),1)];
SIPP(:,13) = accumarray_expand(SIPP(:,11),SIPP(:,7),fcn);
SIPP(:,13) = SIPP(:,13)-SIPP(:,11);
names(1,13) = {'Demeaned exp'};

reg = ols(SIPP(:,12),SIPP(:,13));

gain = reg.beta;

end