function [corr_prod,mean_R2,contri,contri_mean] = contri_wage_variance(NLSY_panel)
%computes contribution of individual, job effects and meassurement error
%to wage dispersion

T = max(NLSY_panel(:,12));

initial = zeros(max(NLSY_panel(:,7)),2); %vector of innitial abilities
initial(:,1) = NLSY_panel(NLSY_panel(:,12)==1,4); %individual prod
initial(:,2) = NLSY_panel(NLSY_panel(:,12)==1,7); %id

NLSY_panel(NLSY_panel(:,2)==2,:) = []; %delete unemployed worker
NLSY_panel(:,6) = log(NLSY_panel(:,6));

% compute vector of correlation between initial ability and individual
% wage component of workers
corr_prod = zeros(T-5,1);
for t = 6:T
    period_prod = zeros(sum(NLSY_panel(:,12)==t),2); %ind productivities in period t
    period_prod(:,1) = NLSY_panel(NLSY_panel(:,12)==t,4);
    period_prod(:,2) = NLSY_panel(NLSY_panel(:,12)==t,7);
    period_initial = zeros(sum(NLSY_panel(:,12)==t),2); %relevant innitial prod for period t
    period_initial(:,2) = period_prod(:,2);
    period_initial(:,1) = initial(period_initial(:,2),1);
    corr = corrcoef(period_initial(:,1),period_prod(:,1));
    corr_prod(t-5,1) = corr(1,2);
end

obs = zeros(T-5,1);
R2 = zeros(T-5,1);
coeficients = zeros(T-5,2);
contri = zeros(T-5,4); %contribution of each element of variance decomposition 
for t = 6:T
    obs(t-5,1) = sum(NLSY_panel(:,12)==t);
    X = zeros(obs(t-5,1),3);
    X(:,1) = ones(sum(NLSY_panel(:,12)==t),1); 
    X(:,2) = NLSY_panel(NLSY_panel(:,12)==t,4); %ind prod
    X(:,3) = NLSY_panel(NLSY_panel(:,12)==t,5); %firm prod
    Y = NLSY_panel(NLSY_panel(:,12)==t,6);
    reg = ols(Y,X);
    R2(t-5,1) = reg.rsqr;
    coeficients(t-5,1) = reg.beta(2,1);
    coeficients(t-5,2) = reg.beta(3,1);
    %compute variances of interest
    var_wage = var(Y);
    var_indprod = var(X(:,2));
    var_firmprod = var(X(:,3));
    
    %computing covariances
    cov_indprod_firmprod = cov(X(:,2),X(:,3));
    cov_indprod_firmprod = cov_indprod_firmprod(1,2);
    
    %computing approximate shares of contribution
    total_variance = var_indprod+var_firmprod+2*cov_indprod_firmprod;
    contri(t-5,1) =  var_indprod/total_variance;
    contri(t-5,2) =  var_firmprod/total_variance;
    contri(t-5,3) =  2*cov_indprod_firmprod/total_variance;
    contri(t-5,4) = var_wage - total_variance;
end

mean_R2 = sum(R2/length(R2));
%calculate mean dispersion shares
total = cumsum(obs);
obs = obs./total(end,1);
contri_mean = sum(contri.*repmat(obs,1,4));

end