clear all
close all
clc

%main file
%% Routine

beta = 0.9967;        %discount factor
job_prob = 0.124;     %off the job offer rate
destruct = 0.0065;    %exogenous destruction
job_offer = 0.043195;  %on the job offer
job_force = 0.0955;  %reallocation shock
death = 1/396;       %death probability  
mu = 0.002474;       %experience gains
delta = 0.00230;   %skill loss

na = 1500; %number of grid points for worker productivity
nasim = 5000; %during distribution function
amax = 15;  %maximum individual prod
amax_sim = amax;
amin = -2;  %minimum individual prod
agrid = linspace(amin,amax,na)';   %grid for worker productivity
agridsim = linspace(amin,amax_sim,nasim)';  %during distribution function

%job component
mean_f = 0;
fnodes = 100; %number of grid points
gamma.std = 0.1626; %standard deviation 

gamma.n = Norm(fnodes,mean_f,gamma.std)'; %grid points of firm productivity
gamma.w = repmat(1/fnodes,fnodes,1); %probability of job offer

bmin = 0;     %minimum unemployment benefits
bmax = 292*4; %maximum benefits 
lmin = 0;     %minimum value of leissure
rr_b = 0.25;  %replacement rate for benefits
rr_l = 0.15;  %replacement rate for value of leissure

% Generate nodes and weights for quadrature integration
nnodes = 10;
epsilon.stde = (sqrt(0.0027)/1.09)/2.936; %standard deviation of shocks 
[epsilon.n, epsilon.w] = hernodes(nnodes);
epsilon.n = epsilon.n*epsilon.stde*sqrt(2); %grid points
epsilon.w = epsilon.w/sqrt(pi);             %probability of occurence
ind_weightE = repmat(repmat(epsilon.w',na,1), [1 1 fnodes]); 
ind_weightU = repmat(epsilon.w',na,1); 
prod_l = repmat(agrid,1,nnodes)+repmat(epsilon.n',na,1);

% unemployment process
epsilon.stdu = epsilon.stde;

% Transition grid
Aprime = NaN(10*na,2);
for i1 = 1:na
    for i2 = 1:10
        Aprime((i1-1)*10+i2,1) = min(amax,max(amin, agrid(i1) + mu + epsilon.n(i2)));
        Aprime((i1-1)*10+i2,2) = min(amax,max(amin, agrid(i1) - delta + epsilon.n(i2)));
    end
end

%Newborn productivity processes
epsilon.stdnewborn = 0.293; %innitial dispersion 
newmean = 5.618; %mean wage potential


% Make transition matrices and distribution for newborns
Prob.Newborn = zeros(nasim,1);
Prob.Newborn(1) = normcdf(agridsim(1),newmean,epsilon.stdnewborn);
Prob.Newborn(2:end) = diff(normcdf(agridsim,newmean,epsilon.stdnewborn));
Prob.Newborn(end) = Prob.Newborn(end)+1-normcdf(agridsim(end),newmean,epsilon.stdnewborn);
Prob.Newborn(Prob.Newborn<10^(-24)) = 0;
Prob.Newborn = Prob.Newborn/sum(Prob.Newborn);

% wage transitions employed and unemployed and firms
N = nnodes+1;
[PI, step] = transitions(N,epsilon.stde,agridsim); 

ProbE1 = zeros(nasim,nasim);
ProbU = zeros(nasim,nasim);

for aa = 1:nasim
    index.E1(aa,1) = min(sum(agridsim(aa,1)+mu>=agridsim)+1,nasim);
    for bb = 1:N
        ProbE1(aa,min(nasim,max(1,index.E1(aa,1)-step*((N-1)/2)+(bb-1)*step))) = ProbE1(aa,min(nasim,max(1,index.E1(aa,1)-step*((N-1)/2)+(bb-1)*step)))+...
            (1-(agridsim(index.E1(aa,1),1)-min(amax_sim,agridsim(aa,1)+mu))/(agridsim(2,1)-agridsim(1,1)))*PI(bb);
        ProbE1(aa,min(nasim,max(1,index.E1(aa,1)-1-step*((N-1)/2)+(bb-1)*step))) =ProbE1(aa,min(nasim,max(1,index.E1(aa,1)-1-step*((N-1)/2)+(bb-1)*step)))+...
            (((agridsim(index.E1(aa,1),1)-min(amax_sim,agridsim(aa,1)+mu))/(agridsim(2,1)-agridsim(1,1))))*PI(bb); %1. Zeile: Masse die aus 1 zu i geht
    end
end

for aa = 1:nasim 
    index.U(aa,1) = max(sum(agridsim(aa,1)-delta>=agridsim),1);
    for bb = 1:N
        ProbU(aa,min(nasim,max(1,index.U(aa,1)-step*((N-1)/2)+(bb-1)*step))) = ProbU(aa,min(nasim,max(1,index.U(aa,1)-step*((N-1)/2)+(bb-1)*step)))+...
            (1-(max(agridsim(aa,1)-delta-agridsim(index.U(aa,1)),0))/(agridsim(2,1)-agridsim(1,1)))*PI(bb);
        ProbU(aa,min(nasim,max(1,index.U(aa,1)-1-step*((N-1)/2)+(bb-1)*step))) = ProbU(aa,min(nasim,max(1,index.U(aa,1)-1-step*((N-1)/2)+(bb-1)*step)))+...
            ((max(agridsim(aa,1)-delta-agridsim(index.U(aa,1)),0))/(agridsim(2,1)-agridsim(1,1)))*PI(bb);
    end
end


ProbE1 = ProbE1';
ProbE1 = sparse(ProbE1);
ProbU = ProbU';
ProbU = sparse(ProbU);

%probability to go to a specific job conditional on current job
prob_loss = 1-cumsum(gamma.w); %probability that employee is hired from outside job
aux = (tril(ones(fnodes))')-eye(fnodes,fnodes);
Prob.firm = (repmat(gamma.w',fnodes,1).*aux); 
for tt = 1:fnodes-1
    Prob.firm(tt,:) = Prob.firm(tt,:)/sum(Prob.firm(tt,:));
end

tol.val = 10^(-5);  %tolerance for value function iteration
tol.dist = 1e-9;    %tolerance for distribution function iteration
tol.b = 10^(-3);    %tolerance for value iteration
tol.move = 3*10^(-4);   %tollerance level for calibrating on the job search efficiency

up = 0.5; %updating weight
    
%% Procedure

%Initialization

%wage function and benefit functions
w = exp((repmat(agrid,1,fnodes))+(repmat(gamma.n',na,1)));  
wnew = w;


b(:,1) = squeeze(0.25*sum(w,2)/fnodes);        
L(:,1) = max(lmin,squeeze(0.15*sum(w,2)/fnodes));
b = min(bmax,b);

%value function
VEold = zeros(na,fnodes);
VUold = zeros(na,1);

%distribution function
fe = zeros(nasim,fnodes); 
fu = zeros(nasim,1);  
fu(sum(agridsim<=0),1) = 0.05;  % 5% are unemployed 
fe(sum(agridsim<=1),:) = reshape(0.95*gamma.w,1,fnodes);  

count=0;
critmove = 1; 
while critmove>tol.move

critb=1;
while critb>tol.b
    %% VFI of the household
    crit = 1;
    while crit>tol.val
        
                [VEnew,VUnew] = VFI_mex(VEold,VUold,agrid,...
                    gamma.w,epsilon.w,Aprime,w,b,...
                    L,job_offer,job_force,destruct,beta,job_prob,death);
%         [VEnew,VUnew] = VFI_benefits(VEold,VUold,agrid,amin,mu,delta,na,fnodes,gamma.w,prod_l,ind_weightE,ind_weightU,amax,w,b,L,job_offer,job_force,destruct,beta,job_prob,death);
        crit = max(max(max(max(max(abs(VUold-VUnew)))),max(max(max(abs(VEold-VEnew))))));
        VEold = VEnew;
        VUold = VUnew;
    end
    
    breaklevel_1 = breaklevel(VEnew,VUnew,fnodes,agrid,na); %policy to accept jobs
    
    %% Distribution Function Iteration
    w_dens = interp1(agrid,w,agridsim,'spline','extrap');
    
    [fenew,funew,mass_offers_headhunt,mass_force_distribute,mass_quitting,prob,wage_gain_switching] = ...
        Dist(fe,fu,nasim,agridsim,fnodes,ProbE1,ProbU,destruct,job_offer,prob_loss,job_prob,breaklevel_1,gamma.w,Prob.Newborn,Prob.firm,job_force,tol.dist,w_dens,death);
    
    fe = fenew;
    fu = funew;
    
    %compute aggregates
    e = sum(sum(fenew));
    u = sum(funew);
    
    %update benefit scheduele
    [bnew, Lnew] = benefits(agridsim,agrid,fenew,na,w,fnodes,bmin,bmax,rr_b,rr_l);
    critb = max(max(max(abs(b-bnew))),max(max(abs(L-Lnew))));
    b = bnew;
    L = Lnew;
    
end
count = count+1;

%update job_offer
critmove = abs(prob.move-0.015);

if critmove> tol.move 
    if prob.move>0.015
        track(count,1) = 1;
        track(count,2) = job_offer;
    else
        track(count,1) = -1;
        track(count,2) = job_offer;
    end
    if count==1 %first try
        if prob.move>0.015
            job_offer = job_offer-(0.1*job_offer); %large 10% move
        else
            job_offer = job_offer+(0.1*job_offer);
        end
    else %already past observations avaliable
        if prob.move>0.015 
            if track(count-1,1) == 1 %to the left of current point
                job_offer = job_offer-(0.1*job_offer); %large 10% move
            else %between the current point and last try
                job_offer = (job_offer+track(count-1,2))/2;
            end
        else
            if track(count-1,1) == -1 %to the right of current point
                job_offer = job_offer+(0.1*job_offer);
            else %between the current point and last try
                job_offer = (job_offer+track(count-1,2))/2;
            end
        end
    end
    
end

if job_offer>1
    critfind = 0;
end

end %end move loop

%% compute distribuitions

%compute the mean wage
fenew(fenew<eps) = 0;
fdist = fenew./sum(sum(sum(fenew))); %normalize to one
mean_wage = sum(sum(sum(fdist.*w_dens)));

%% Simulating SIPP

H = 50000; %simulate H individuals 50000
R = 48; %each individual is simulated for 48 month
corre.before = 1; %check correctnes of initialization
corre.after = 1; %check correctnes ate end of simmulation
sipp.trim = 0; %shall we trim the wage distribution
sipp.error = 1; %simulate with error
sipp.baseline = 1; %baseline or alternative clibration?

[SIPP.panel,correct.sipp,share_down] = sipp_sim(H,R,corre,epsilon,fenew,funew,e,u,agridsim,gamma,nasim,...
    fnodes,amax,amin,delta,mu,wnew,agrid,destruct,job_offer,job_force,death,job_prob,breaklevel_1,ProbE1,ProbU,prob_loss,Prob.Newborn,Prob.firm,sipp);

names = {'LC' 'emp' 'd EE' 'A' 'Gamma' 'wage' 'id'};
SIPP.panel(SIPP.panel(:,1)==0,:) = []; %delete observations when agents are dead

SIPP_panel = SIPP.panel;
save('SIPP_panel.mat','SIPP_panel');
clear SIPP_panel;
%% calculate variance of wages within and between job holdings

corre.flow = 0; %shall we compute flow rates
outliers = 0; %shall we delete outliers in growth
trim = 0; %shall we trim
ma = sipp.error; %do we have ma error
[within,between,prob.loss,growth_max,growth_min,s] = wage_variance(SIPP.panel,corre.flow,trim,outliers,ma);
within.mean_wage = mean_wage;

%% simulating NLSY for 33 years

H = 30000;
R = 397; 
nlsy.stats = 0; %compute further statistics?
nlsy.trim = 0; %shall we trim the wage distribution
corre.nlsy = 1; %shall we check correctness of simmulation
nlsy.baseline = 1;
[NLSY.panel,NLSY.panel_error,correct.nlsy] = nlsy_sim(H,R,corre,epsilon,agridsim,gamma,nasim,...
    fnodes,amax,amin,delta,mu,wnew,agrid,destruct,job_offer,job_force,death,job_prob,newmean,breaklevel_1,ProbE1,ProbU,prob_loss,Prob.Newborn,Prob.firm,nlsy.stats,nlsy.trim,nlsy.baseline,w_dens);

NLSY_error = NLSY.panel_error;
save('NLSY_error.mat','NLSY_error');
clear NLSY_error;
%% Sample SIPP from NLSY

NLSY.SIPP = create_sipp_nlsy(NLSY.panel_error,R);
NLSY_SIPP = NLSY.SIPP;
save('NLSY_SIPP.mat','NLSY_SIPP');
clear NLSY_SIPP;

%% reduced form depretiation

depretiation = comp_depre(NLSY.SIPP,names);

%% Mm over the life cycle

Mm.age = Mm_age(NLSY.SIPP);
Mm_age_theory=Mm.age;
save('Mm_age_theory.mat','Mm_age_theory');
%% regression analysis preparation

panel.regress = NLSY.SIPP;

panel.regress(panel.regress(:,2)==2,2) = 0; %make employment status a dummy variable with 0 (unemployed) and 1

panel.regress(panel.regress(:,2)==0,:) = []; %delete unemployed worker

%% true estimator of Mm-ratio

Y_true = log(panel.regress(:,6));
X_true = zeros(length(panel.regress),3);
X_true(:,1) = ones(length(X_true),1); % constant
X_true(:,2) = panel.regress(:,4); %ind. prod.
X_true(:,3) = panel.regress(:,5); %firm prod.

results_true = ols(Y_true,X_true);

% compute explained variance due to firm effects
y_no_firm = X_true(:,1)*results_true.beta(1,1)+X_true(:,2)*results_true.beta(2,1);
u_no_firm = Y_true-y_no_firm;
SSR = sum(u_no_firm(:,1).^2);
mean_y_true = sum(Y_true)/length(Y_true);
SST = sum((Y_true-mean_y_true).^2);
R2 = 1-(SSR/SST);

wage_dispersion =  X_true(:,3)*results_true.beta(3,1);
wage_dispersion = exp(wage_dispersion);

wage_dispersion = sort(wage_dispersion);
mean_wage_disperse = sum(wage_dispersion)/length(wage_dispersion);
min_wage_disperse = min(wage_dispersion);
min_wage_disperse1 = wage_dispersion(floor(length(wage_dispersion)/100));
min_wage_disperse5 = wage_dispersion(floor(length(wage_dispersion)/20));
min_wage_disperse10 = wage_dispersion(floor(length(wage_dispersion)/10));

Mm.disperse = mean_wage_disperse/min_wage_disperse; 
Mm.disperse1 = mean_wage_disperse/min_wage_disperse1; 
Mm.disperse5 = mean_wage_disperse/min_wage_disperse5; 
Mm.disperse10 = mean_wage_disperse/min_wage_disperse10;

%% aproximated estimator

Y_app = log(panel.regress(:,6));
X_app = zeros(length(panel.regress),2);
X_app(:,1) = ones(length(X_app),1); % constant
X_app(:,2) = panel.regress(:,9); %experience

results_app = ols(Y_app,X_app);

wage_dispersion = exp(results_app.resid);
app_var = var(results_app.resid);
app_gini = ginicoeff(wage_dispersion);

wage_dispersion = sort(wage_dispersion);
mean_wage_disperse = sum(wage_dispersion)/length(wage_dispersion);
min_wage_disperse = min(wage_dispersion);
min_wage_disperse1 = wage_dispersion(floor(length(wage_dispersion)/100));
min_wage_disperse5 = wage_dispersion(floor(length(wage_dispersion)/20));
min_wage_disperse10 = wage_dispersion(floor(length(wage_dispersion)/10));

Mm.disperse_app = mean_wage_disperse/min_wage_disperse; 
Mm.disperse1_app = mean_wage_disperse/min_wage_disperse1; 
Mm.disperse5_app = mean_wage_disperse/min_wage_disperse5; 
Mm.disperse10_app = mean_wage_disperse/min_wage_disperse10;

%% calculating states
NLSY.SIPP(:,9) = []; %delete experience
NLSY.SIPP(:,8) = []; %delete age

NLSY.SIPP(2:end,3) = NLSY.SIPP(1:end-1,3);%move job switch one ahead
NLSY.SIPP = [NLSY.SIPP zeros(length(NLSY.SIPP),1)];  %add column for number of job switches until period t
fcn = @(x){cumsum(x)}; 
NLSY.SIPP(:,8) = accumarray_expand(NLSY.SIPP(:,3),NLSY.SIPP(:,7),fcn);
names(1,8) = {'sum d EE'};

NLSY.SIPP = [NLSY.SIPP zeros(length(NLSY.SIPP),1)];  %add column for indicator of change in agent
NLSY.SIPP(2:end,9) = NLSY.SIPP(2:end,7)-NLSY.SIPP(1:end-1,7); 
NLSY.SIPP(NLSY.SIPP(:,9)~=0,9) = 1; %make it indicator function
names(1,9) = {'d id'};

NLSY.SIPP = [NLSY.SIPP zeros(length(NLSY.SIPP),1)];  %add column for indicator of job transitions from UE until period t
NLSY.SIPP(2:end,10) = NLSY.SIPP(2:end,2)-NLSY.SIPP(1:end-1,2);
NLSY.SIPP(NLSY.SIPP(:,10)==1,10) = 0;    %set job loses to zero (includes artificial initial job loss)
NLSY.SIPP(NLSY.SIPP(:,10)==-1,10) = 1;    %set job findings to one
NLSY.SIPP(NLSY.SIPP(:,9)==1,10) = 0; %zero where new agent starts
names(1,10) = {'d UE'};

NLSY.SIPP = [NLSY.SIPP zeros(length(NLSY.SIPP),1)];  %add column for number of job findings from UE in period t
fcn = @(x){cumsum(x)}; 
NLSY.SIPP(:,11) = accumarray_expand(NLSY.SIPP(:,10),NLSY.SIPP(:,7),fcn);
names(1,11) = {'sum d UE'};

NLSY.SIPP = [NLSY.SIPP zeros(length(NLSY.SIPP),1)];  %add column for total number of jobs moved to until period t
NLSY.SIPP(:,12) = NLSY.SIPP(:,8)+NLSY.SIPP(:,11);
names(1,12) = {'sum d UE+ d EE'};


%compute period number
NLSY.SIPP = [NLSY.SIPP ones(length(NLSY.SIPP),1)];  %add column for period the agent is in
fcn = @(x){cumsum(x)}; 
NLSY.SIPP(:,13) = accumarray_expand(NLSY.SIPP(:,13),NLSY.SIPP(:,7),fcn);
names(1,13) = {'Period'};

%% Hornstein et al. estimator 

Hornstein = Hornstein_SIPP(NLSY.SIPP,names);


%% reduced form experience
experience = comp_exp(NLSY.panel_error,names(1:7));

%% calculating states
NLSY.panel = [NLSY.panel zeros(length(NLSY.panel),1)];  %add column for number of job switches until period t
NLSY.panel(:,3) = [0; NLSY.panel(1:end-1,3)]; %move EE one front
fcn = @(x){cumsum(x)}; 
NLSY.panel(:,8) = accumarray_expand(NLSY.panel(:,3),NLSY.panel(:,7),fcn);

NLSY.panel = [NLSY.panel zeros(length(NLSY.panel),1)];  %add column for indicator of job transitions from UE until period t
NLSY.panel(2:end,9) = NLSY.panel(2:end,2)-NLSY.panel(1:end-1,2);
NLSY.panel(NLSY.panel(:,9)==1,9) = 0;    %set job loses to zero (includes artificial initial job loss)
NLSY.panel(NLSY.panel(:,9)==-1,9) = 1;    %set job findings to one

NLSY.panel = [NLSY.panel zeros(length(NLSY.panel),1)];  %add column for number of job findings from UE in period t
NLSY.panel(:,10) = accumarray_expand(NLSY.panel(:,9),NLSY.panel(:,7),fcn);

NLSY.panel = [NLSY.panel zeros(length(NLSY.panel),1)];  %add column for total number of jobs held until period t
NLSY.panel(:,11) = NLSY.panel(:,8)+NLSY.panel(:,10);
% 8: number of EE movements 10: number of UE movements 11: total number of
% movements

%compute age
NLSY.panel = [NLSY.panel ones(length(NLSY.panel),1)];  %add column for period the agent is in
NLSY.panel(:,12) = accumarray_expand(NLSY.panel(:,12),NLSY.panel(:,7),fcn);

NLSY.panel(:,3) = [NLSY.panel(2:end,3); 0]; %move EE one back
NLSY.panel_error(:,1:5) = NLSY.panel(:,1:5);
NLSY.panel_error(:,7:12) = NLSY.panel(:,7:12);
%% calculating contributions to log wage variances

[corr_prod,mean_R2,contribution,contri_mean] = contri_wage_variance(NLSY.panel_error);

%% calculate Topel Ward statistics

TW = tw_stats(NLSY.panel_error);

%% graph

%contribution to wage variance
K = zeros(length(contribution),1);
K(:,1) = contribution(:,3);
U = zeros(length(contribution),4);
U(:,1) = max(0,contribution(:,3));
U(:,2) = contribution(:,2);
U(:,3) = contribution(:,4);
U(:,4) = (0.9*ones(length(U),1)-U(:,2)-U(:,1)-U(:,3));
U = U*100;
K = K*100;
time = 6:397;
time = [time./12]'+22;
figure(13)
l=area(repmat(time,1,1),K);
set(l(1),'FaceColor',[0.1 0.1 0.1])
hold on
u=area(repmat(time,1,4),U);
set(u(1),'FaceColor',[0.2 0.2 0.2])
set(u(2),'FaceColor',[0.5 0.5 0.5])
set(u(3),'FaceColor',[0.8 0.8 0.8])
set(u(4),'FaceColor',[0.95 0.95 0.95])
legend(u(:,1:4),'Sorting','Job heterogeneity','Measurement error','Worker heterogeneity')
hold off
axis tight
xlabel('Age','fontsize',12,'fontweight','bold')
ylabel('% contribution to wage variance','fontsize',12,'fontweight','bold')


%% Tables 

%Table 5
Mm.disperse1_app
Mm.disperse5_app
Mm.disperse10_app
app_gini
app_var


%Table 6
job_offer
gamma.std 
epsilon.stde 
epsilon.stdnewborn

%Table 7
between.ave_gain
between.ave_loss

%E1
TW.wgr12_jtj
TW.wgr48_jtj
TW.wgr72_jtj
TW.wgr108_jtj
TW.wgr_jtj