function [NLSY_panel,NLSY_panel_error,correct] = nlsy_sim(H,R,corre,epsilon,agridsim,gamma,nasim,...
    fnodes,amax,amin,delta,mu,wnew,agrid,destruct,job_offer,job_force,death,job_prob,newmean,breaklevel_1,ProbE1,ProbU,prob_loss,Prob_Newborn,Prob_firm,further,trim,baseline,w_dens)

%simulates the model according to the NLSY simmulation
NLSY.study = zeros(H,7,R);
names = {'Alive' 'Emp' 'delta J' 'A' 'Gamma' 'w' 'i'};

%person in first dimension, (allive, employment state (2), switch job in period t, idiosyncratic
%productivity, firm productivity, wage, individual indicator) in second dimension and month of
%simulation in third dimension


rand('seed',74924);  
randn('seed',2103);

NLSY.prod_initial = max(amin,epsilon.stdnewborn*randn(H,1)+newmean);
NLSY.heart = rand(H,R);
NLSY.destruct = rand(H,R);
NLSY.on_offer = rand(H,R);
NLSY.force_offer = rand(H,R);
NLSY.offer = gamma.std*randn(H,R);
NLSY.off_offer = rand(H,R);
NLSY.prod = epsilon.stde*randn(H,R);
NLSY.error = 1; %simulate with error


NLSY.study(:,1,1) = 1; %start allive
NLSY.study(:,2,1) = 2; %unemployed 
NLSY.study(:,3,1) = 0;
NLSY.study(:,4,1) = NLSY.prod_initial;
NLSY.study(:,5,1) = 0;
NLSY.study(:,6,1) = 0;


for r = 1:R-1 
   
    NLSY.study(:,7,r) = 1:H;                                                                   
    NLSY.study(NLSY.study(:,2,r)==2,4,r+1) = min(amax,max(amin,NLSY.study(NLSY.study(:,2,r)==2,4,r)-delta+NLSY.prod(NLSY.study(:,2,r)==2,r+1))); %productivity transition of unemployed
    NLSY.study(NLSY.study(:,2,r)==1,4,r+1) = min(amax,max(amin,NLSY.study(NLSY.study(:,2,r)==1,4,r)+mu+NLSY.prod(NLSY.study(:,2,r)==1,r+1))); %productivity transition of employed
    NLSY.study(NLSY.study(:,1,r)==1,1,r+1) = 1 -(NLSY.heart(NLSY.study(:,1,r)==1,r+1) <= death); %agents die
    NLSY.study(NLSY.study(:,2,r)==2,6,r) = 0; %wage of unemployed
    aux_w = find_index(NLSY.study(:,4,r),agrid); %index of current productivity state
    index.le = (NLSY.study(:,1,r) == 1).*(NLSY.study(:,1,r+1) == 1).*(NLSY.study(:,2,r) == 1); %worker is employed, allive and stay allive
    index.lu = (NLSY.study(:,1,r) == 1).*(NLSY.study(:,1,r+1) == 1).*(NLSY.study(:,2,r) == 2); %worker is unemployed, allive and stay allive
    index.ld = (NLSY.study(:,1,r) == 1).*(NLSY.study(:,1,r+1)==0); %worker dies 
    index.d = (NLSY.study(:,1,r) == 0); %worker is dead
    for h = 1:H
        %compute todays wage
        if NLSY.study(h,2,r) == 1 %worker is employed
            NLSY.study(h,6,r) = max(0.0001,interp1_l_mex(gamma.n,squeeze(wnew(aux_w(h,1),:))',NLSY.study(h,5,r)));    
        end
        %compute end of period transitions
        if index.le(h,1) %employed and stay allive
            if NLSY.destruct(h,r+1) > destruct %job continues
                if NLSY.on_offer(h,r+1) <= job_offer %worker gets on the job offer
                    offer_index = NLSY.offer(h,r+1);
                    if NLSY.force_offer(h,r+1) > job_force    %regular on the job offer
                        NLSY.study(h,5,r+1) = max(offer_index,NLSY.study(h,5,r));
                        if ((NLSY.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),NLSY.study(h,5,r+1)))*...
                                (NLSY.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),NLSY.study(h,5,r+1))))  %does not want to become unemployed
                            NLSY.study(h,2,r+1) = 1;
                            if NLSY.study(h,5,r+1) ~= NLSY.study(h,5,r) %worker switched job
                                NLSY.study(h,3,r) = 1;
                            end
                        else %worker chooses unemployment
                            NLSY.study(h,5,r+1) = 0;
                            NLSY.study(h,2,r+1) = 2;
                        end
                    else %forced job offer
                        if ((NLSY.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),offer_index))*...
                                (NLSY.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),offer_index)))  %does accept job
                            NLSY.study(h,3,r) = 1;
                            NLSY.study(h,2,r+1) = 1;
                            NLSY.study(h,5,r+1) = offer_index;
                        else %worker chooses unemployment
                            NLSY.study(h,2,r+1) = 2;
                            NLSY.study(h,5,r+1) = 0;
                        end
                    end
                else %no job offer
                    NLSY.study(h,5,r+1) = NLSY.study(h,5,r);
                    if ((NLSY.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),NLSY.study(h,5,r+1)))*...
                            (NLSY.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),NLSY.study(h,5,r+1))))  %does not want to break
                        NLSY.study(h,2,r+1) = 1;
                        NLSY.study(h,5,r+1) = NLSY.study(h,5,r);
                    else
                        NLSY.study(h,2,r+1) = 2;
                        NLSY.study(h,5,r+1) = 0;
                    end
                end
            else %job is destroyed
                NLSY.study(h,2,r+1) = 2;
            end
            
        elseif index.lu(h,1) %worker is unemployed and continues living
            if NLSY.off_offer(h,r+1) <= job_prob %worker gets a job offer
                offer_index = NLSY.offer(h,r+1);
                if ((NLSY.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),offer_index))*...
                        (NLSY.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),offer_index)))  %does accept job
                    NLSY.study(h,2,r+1) = 1;
                    NLSY.study(h,5,r+1) = offer_index;
                else
                    NLSY.study(h,2,r+1) = 2;
                end
            else %woker does not get a job offer
                NLSY.study(h,2,r+1) = 2;
            end
            
        elseif index.ld(h,1) %worker dies
            NLSY.study(h,:,r+1) = 0;
        elseif index.d(h,1) %worker is dead
            NLSY.study(h,:,r) = 0;
        end
    end
end

%compute wages in last period
aux_w = find_index(NLSY.study(:,4,end),agrid); %index of current productivity state
for h = 1:H
    if NLSY.study(h,2,end) == 1 %worker is employed
        NLSY.study(h,6,end) = max(0.0001,interp1_l_mex(gamma.n,squeeze(wnew(aux_w(h,1),:)),NLSY.study(h,5,end)));    
    end
end
NLSY.study(:,7,end) = 1:H; 
NLSY.study(NLSY.study(:,1,end)==0,:,end) = 0; 


%correctness of end result 
if corre.nlsy
    correct = check_nlsy(NLSY.study,fnodes,nasim,gamma.n,agridsim,R,ProbE1,ProbU,destruct,job_offer,death,prob_loss,job_prob,breaklevel_1,gamma.w,Prob_Newborn,Prob_firm,job_force,w_dens);
end


%collapse to 2d matrix
NLSY_panel = zeros(H*R,7);
for h = 1:H
    transform = squeeze(NLSY.study(h,:,1:end));
    transform = transform';
    NLSY_panel(1+(h-1)*R:h*R,:) = transform;
end

NLSY_panel(NLSY_panel(:,1)==0,:) = []; %delete observations when agents are dead

if NLSY.error
    spell = 0; %how shall spell be computed
    NLSY_panel_error = meas_error(NLSY_panel,baseline,spell);
end

if trim
    trim_up = prctile(NLSY_panel(NLSY_panel(:,2)==1,6),99);
    trim_low = prctile(NLSY_panel(NLSY_panel(:,2)==1,6),1);
    indicator_trim = ((NLSY_panel(:,6)>trim_up)+(NLSY_panel(:,6)<trim_low)).*(NLSY_panel(:,6)==1);
    NLSY_panel(indicator_trim==1,:) = [];
end

if corre.nlsy==0
    correct = 0;
end

end