function [SIPP_panel,correct,share_down] = sipp_sim(H,R,corre,epsilon,fenew,funew,e,u,agridsim,gamma,nasim,...
    fnodes,amax,amin,delta,mu,wnew,agrid,destruct,job_offer,job_force,death,job_prob,breaklevel_1,ProbE1,ProbU,prob_loss,Prob_Newborn,Prob_firm,sipp)

%simulate a worker panel from stationary distribution according to SIPP

SIPP.study = zeros(H,7,R);
names = {'Alive' 'Emp' 'delta J' 'A' 'Gamma' 'w' 'i'};
%person in first dimension, (employment state (2), switch job in period t, idiosyncratic
%productivity, firm productivity, wage, individual indicator) in second dimension and month of
%simulation in third dimension

rand('seed',3584);  
randn('seed',1745103);

SIPP.emp = rand(H,R);
SIPP.benefit = rand(H,R);
SIPP.heart = rand(H,R);
SIPP.prod_initial = rand(H,1);
SIPP.firm_initial = rand(H,1);
SIPP.prod = epsilon.stde*randn(H,R);
SIPP.destruct = rand(H,R);
SIPP.on_offer = rand(H,R);
SIPP.force_offer = rand(H,R);
SIPP.offer = gamma.std*randn(H,R);
SIPP.off_offer = rand(H,R);

%% Initialization
SIPP.study(:,1,1) = 1; %all are allive

%initial employment status
SIPP.study(SIPP.emp(:,1)<=e,2,1) = 1;
SIPP.study(SIPP.emp(:,1)>e,2,1) = 2; 

asum=cumsum((sum(fenew(:,:),2))./e); 
gamasum=cumsum(squeeze((sum(fenew(:,:),1))./e));

%innital individual productivity state
fusum=cumsum(funew./u);

%productivities employed
aux_n = (SIPP.study(:,2,1)==1);
aux=find_index(SIPP.prod_initial(logical(aux_n),1),asum);
SIPP.study(logical(aux_n),4,1) = agridsim(max(1,aux+1));
aux=find_index(SIPP.firm_initial(logical(aux_n),1),gamasum');
SIPP.study(logical(aux_n),5,1) = gamma.n(max(1,aux+1));

%productivity unemployed 
aux_n = (SIPP.study(:,2,1)==2);
aux=find_index(SIPP.prod_initial(logical(aux_n),1),fusum);
SIPP.study(logical(aux_n),4,1) = agridsim(max(1,aux+1));


%correctness of initialization
if corre.before == 1
    correct.before = check_correct(SIPP.study,fenew,funew,e,u,fnodes,nasim,gamma.n,agridsim);
end

%% Simulation

%count jtj movements and share going down due to forced movements
offer = 0;
move_down = 0;
move_force = 0;

for r = 1:R-1 
  
    SIPP.study(:,7,r) = 1:H;                                                                       
    SIPP.study(SIPP.study(:,2,r)==2,4,r+1) = min(amax,max(amin,SIPP.study(SIPP.study(:,2,r)==2,4,r)-delta+SIPP.prod(SIPP.study(:,2,r)==2,r+1))); %productivity transition of unemployed
    SIPP.study(SIPP.study(:,2,r)==1,4,r+1) = min(amax,max(amin,SIPP.study(SIPP.study(:,2,r)==1,4,r)+mu+SIPP.prod(SIPP.study(:,2,r)==1,r+1))); %productivity transition of employed
    SIPP.study(SIPP.study(:,1,r)==1,1,r+1) = 1 -(SIPP.heart(SIPP.study(:,1,r)==1,r+1) <= death); %agents die
    SIPP.study(SIPP.study(:,2,r)==2,6,r) = 0; %wage of unemployed
    aux_w = find_index(SIPP.study(:,4,r),agrid); %index of current productivity state
    index.le = (SIPP.study(:,1,r) == 1).*(SIPP.study(:,1,r+1) == 1).*(SIPP.study(:,2,r) == 1); %worker is employed, allive and stay allive
    index.lu = (SIPP.study(:,1,r) == 1).*(SIPP.study(:,1,r+1) == 1).*(SIPP.study(:,2,r) == 2); %worker is unemployed, allive and stay allive
    index.ld = (SIPP.study(:,1,r) == 1).*(SIPP.study(:,1,r+1)==0); %worker dies 
    index.d = (SIPP.study(:,1,r) == 0); %worker is dead
    for h = 1:H
        %compute todays wage
        if SIPP.study(h,2,r) == 1 %worker is employed
            SIPP.study(h,6,r) = max(0.0001,interp1_l_mex(gamma.n,squeeze(wnew(aux_w(h,1),:))',SIPP.study(h,5,r)));    
        end
        %compute end of period transitions
        if index.le(h,1) %employed and stay allive
            if SIPP.destruct(h,r+1) > destruct %job continues
                if SIPP.on_offer(h,r+1) <= job_offer %worker gets on the job offer
                    offer_index = SIPP.offer(h,r+1);
                    if SIPP.force_offer(h,r+1) > job_force    %regular on the job offer
                        SIPP.study(h,5,r+1) = max(offer_index,SIPP.study(h,5,r));
                        if ((SIPP.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),SIPP.study(h,5,r+1)))*...
                                (SIPP.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),SIPP.study(h,5,r+1))))  %does not want to become unemployed
                            SIPP.study(h,2,r+1) = 1;
                            if SIPP.study(h,5,r+1) ~= SIPP.study(h,5,r) %worker switched job
                                SIPP.study(h,3,r) = 1;
                                offer = offer+1;
                            end
                        else %worker chooses unemployment
                            SIPP.study(h,5,r+1) = 0;
                            SIPP.study(h,2,r+1) = 2;
                        end
                    else %forced job offer
                        if ((SIPP.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),offer_index))*...
                                (SIPP.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),offer_index)))  %does accept job
                            SIPP.study(h,3,r) = 1;
                            SIPP.study(h,2,r+1) = 1;
                            SIPP.study(h,5,r+1) = offer_index;
                            offer = offer+1;
                            move_force = move_force+1;
                            if SIPP.study(h,5,r+1)<SIPP.study(h,5,r)
                                move_down = move_down+1;
                            end
                        else %worker chooses unemployment
                            SIPP.study(h,2,r+1) = 2;
                            SIPP.study(h,5,r+1) = 0;
                        end
                    end
                else %no job offer
                    SIPP.study(h,5,r+1) = SIPP.study(h,5,r);
                    if ((SIPP.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),SIPP.study(h,5,r+1)))*...
                            (SIPP.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),SIPP.study(h,5,r+1))))  %does not want to break
                        SIPP.study(h,2,r+1) = 1;
                        SIPP.study(h,5,r+1) = SIPP.study(h,5,r);
                    else
                        SIPP.study(h,2,r+1) = 2;
                        SIPP.study(h,5,r+1) = 0;
                    end
                end
            else %job is destroyed
                SIPP.study(h,2,r+1) = 2;
            end
            
        elseif index.lu(h,1) %worker is unemployed and continues living
            if SIPP.off_offer(h,r+1) <= job_prob %worker gets a job offer
                offer_index = SIPP.offer(h,r+1);
                if ((SIPP.study(h,4,r+1) >= interp1_l_mex(gamma.n,breaklevel_1(:,1),offer_index))*...
                        (SIPP.study(h,4,r+1) <= interp1_l_mex(gamma.n,breaklevel_1(:,2),offer_index)))  %does accept job
                    SIPP.study(h,2,r+1) = 1;
                    SIPP.study(h,5,r+1) = offer_index;
                else
                    SIPP.study(h,2,r+1) = 2;
                end
            else %woker does not get a job offer
                SIPP.study(h,2,r+1) = 2;
            end
            
        elseif index.ld(h,1) %worker dies
            SIPP.study(h,:,r+1) = 0;
        elseif index.d(h,1) %worker is dead
            SIPP.study(h,:,r) = 0;
        end
    end
end

%compute wages in last period
aux_w = find_index(SIPP.study(:,4,end),agrid); %index of current productivity state
for h = 1:H
    if SIPP.study(h,2,end) == 1 %worker is employed
        SIPP.study(h,6,end) = max(0.0001,interp1_l_mex(gamma.n,squeeze(wnew(aux_w(h,1),:)),SIPP.study(h,5,end)));    
    end
end
SIPP.study(:,7,end) = 1:H; 
SIPP.study(SIPP.study(:,1,end)==0,:,end) = 0;

%correctness of end result
if corre.after == 1
    correct.after = check_correct2(SIPP.study,fenew,funew,fnodes,nasim,gamma.n,agridsim,R,ProbE1,ProbU,destruct,job_offer,death,prob_loss,job_prob,breaklevel_1,gamma.w,Prob_Newborn,Prob_firm,job_force);
end 
  
%collapse to 2d matrix
SIPP_panel = zeros(H*R,7);
for h = 1:H
    transform = squeeze(SIPP.study(h,:,1:end));
    transform = transform';
    SIPP_panel(1+(h-1)*R:h*R,:) = transform;
end

if sipp.error 
    spell = 0; %how shall spell be computed
    SIPP_panel = meas_error(SIPP_panel,sipp.baseline,spell); 
end

if sipp.trim
%     trim_up = 46.6282*40*4;
    trim_up = 10^9;
    trim_low = 2.3095*40*4;
    indicator_trim = (SIPP_panel(SIPP_panel(:,2)==1,6)>trim_up)+(SIPP_panel(SIPP_panel(:,2)==1,6)<trim_low);
    SIPP_panel(indicator_trim==1,:) = [];
end

if ((corre.before==0).*(corre.after==0))
    correct = 0;
end

share_down.down = move_down/offer;
share_down.force = move_force/offer;
end