function [within,between,prob_jtj_loss,growth_max,growth_min,p] = wage_variance(SIPP_panel,flow,trim,outliers,ma)
%calculates statistics of within spell and between spell wages

n = max(SIPP_panel(:,7)); %number of agents

%shift job switch indicator one ahead
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)]; 
SIPP_panel(2:end,8) = SIPP_panel(1:end-1,3);

%find starting point of new agent
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,9) = SIPP_panel(2:end,7)-SIPP_panel(1:end-1,7);
SIPP_panel(SIPP_panel(:,9)~=0,9) = 1;

if flow 
    indi_last = [SIPP_panel(2:end,9)~=1; 0]; %put a zero on last observation of observation spell
    E = 0;
    for i = 1:n
        E = E+ sum((SIPP_panel(SIPP_panel(:,7)==i,2)==1).*indi_last(SIPP_panel(:,7)==i)); %number of employment observations where EU or EE could take place
    end

    U = 0;
    for i = 1:n
        U = U + sum((SIPP_panel(SIPP_panel(:,7)==i,2)==2).*indi_last(SIPP_panel(:,7)==i)); %number of unemployment observations where UE could take place
    end

p.ee = sum(SIPP_panel(:,8))/E;
end

%find UE movement
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,10) = SIPP_panel(2:end,2)-SIPP_panel(1:end-1,2);
SIPP_panel(SIPP_panel(:,10)==1,10) = 0;    %set job loses to zero (includes artificial initial job loss)
SIPP_panel(SIPP_panel(:,9)==1,10) = 0;     %zero where new agent starts
SIPP_panel(SIPP_panel(:,10)==-1,10) = 1;    %set job findings to one

if flow
    p.ue = sum(SIPP_panel(:,10))/U;
end

%find EU movement
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,11) = SIPP_panel(2:end,2)-SIPP_panel(1:end-1,2);
SIPP_panel(SIPP_panel(:,11)==-1,11) = 0;    %set job finding to zero
SIPP_panel(SIPP_panel(:,9)==1,11) = 0;     %zero where new agent starts
if flow
    p.eu = sum(SIPP_panel(:,11))/E;
end
SIPP_panel(:,11) = [];
 
SIPP_panel(SIPP_panel(:,2)==2,:) = []; %drop the unemployed

if trim ==1
    trim_up = prctile(SIPP_panel(:,6),99);
    trim_low = prctile(SIPP_panel(:,6),1);
    indicator_trim = (SIPP_panel(:,6)>trim_up)+(SIPP_panel(:,6)<trim_low);
    SIPP_panel(indicator_trim==1,:) = [];
end

%recompute starting point of new agent
SIPP_panel(:,9) = 0;
SIPP_panel(2:end,9) = SIPP_panel(2:end,7)-SIPP_panel(1:end-1,7);
SIPP_panel(SIPP_panel(:,9)>0,9) = 1;
SIPP_panel(1,9) = 1;

%compute change in spell
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(:,11) = SIPP_panel(:,9)+SIPP_panel(:,10);
SIPP_panel(2:end,11) = SIPP_panel(1:end-1,11); %UE and ID will be delayed for wage growth computation. Hence shift them one period
SIPP_panel(:,11) = SIPP_panel(:,11)+SIPP_panel(:,8);
SIPP_panel(:,11) = SIPP_panel(:,11)>0;

%compute wage growth
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,12) = log(SIPP_panel(2:end,6))-log(SIPP_panel(1:end-1,6));
SIPP_panel(SIPP_panel(:,9)==1,:) = []; %delete starting point of new agent
SIPP_panel(SIPP_panel(:,10)==1,:) = []; %delete UE movements
growth_max = max(SIPP_panel(:,12));
growth_min = min(SIPP_panel(:,12));

if outliers
    out_up = prctile(SIPP_panel(:,11),99.25);
    out_low = prctile(SIPP_panel(:,11),0.75);
    indicator_out = (SIPP_panel(:,12)>out_up)+(SIPP_panel(:,12)<out_low);
    indicator_out = indicator_out~=0;
    SIPP_panel(indicator_out==1,:) = [];
end

%compute statistics for on the job changes
otj = SIPP_panel(SIPP_panel(:,8)~=1,:); %drop jtj movements
within.ave_gain = sum(otj(:,12))/length(otj);

%compute statistics for job-to-job movement (observed wages)
jtj = SIPP_panel(SIPP_panel(:,8)==1,:);  %only those observations where j-t-j transition took place
between.ave_gain = sum(jtj(:,12))/length(jtj);
jtj_l = jtj(jtj(:,12)<0,:);
between.ave_loss = sum(jtj_l(:,12))/length(jtj_l);
prob_jtj_loss = length(jtj_l)/length(jtj);

SIPP_panel = [SIPP_panel ones(length(SIPP_panel),1)];

%compute residual within job wage growth
aux = ols(SIPP_panel(SIPP_panel(:,8)==0,12),ones(sum(SIPP_panel(:,8)==0),1));
aux = aux.resid;
SIPP_panel(SIPP_panel(:,8)==0,13) = aux;

%compute residual between job wage growth
aux = ols(SIPP_panel(SIPP_panel(:,8)==1,12),ones(sum(SIPP_panel(:,8)==1),1));
aux = aux.resid;
SIPP_panel(SIPP_panel(:,8)==1,13) = aux;

%computing within variance
within.variance = var(SIPP_panel(SIPP_panel(:,8)==0,13));
within.variance = within.variance(1,1);

%computing between variance
between.variance = var(SIPP_panel(SIPP_panel(:,8)==1,13));
between.variance = between.variance(1,1);

%compute excess variance 
between.excess = between.variance-within.variance;

%recompute within variance if we have MA error
if ma %do we have ma meassurement error
    within.variance_ua = within.variance;
    within.variance = wv(SIPP_panel);
end

if flow == 0
    p = 1;
end

%% smoothed transitions 

% Spell number
SIPP_panel(:,11) = cumsum(SIPP_panel(:,11)); 

l=3;
SIPP_panel(:,14) = count_obs(SIPP_panel(:,11));
SIPP_panel(SIPP_panel(:,14)<l*2,:) = []; %drop short spells 

fcn = @(x){cumsum(x)}; 
SIPP_panel(:,15) = accumarray_expand(ones(length(SIPP_panel),1),SIPP_panel(:,11),fcn); %number of obs in spell

%average by half year
for i = 1:(48/l)-2
    SIPP_panel(:,16) = (SIPP_panel(:,14)>=l*2+((i-1)*l)).*(SIPP_panel(:,14)<l*2+i*l);
    SIPP_panel(logical((SIPP_panel(:,16)==1).*(SIPP_panel(:,15)>2*l+((i-1)*l))),:) = [];
    SIPP_panel(:,16) = 0;
end

 
%renew spell length
SIPP_panel(:,14) = count_obs(SIPP_panel(:,11)); 


%compute mean wage
for i = 1:(48/l)-1
    SIPP_panel(logical((SIPP_panel(:,15)>=1+(i-1)*l).*(SIPP_panel(:,15)<1+i*l)),16) = i;
end

SIPP_panel(:,16) = group([SIPP_panel(:,11) SIPP_panel(:,16)]); 

fcn = @(x){mean(x)};
SIPP_panel(:,17) = accumarray_expand(SIPP_panel(:,6),SIPP_panel(:,16),fcn); %mean wage

%keep only first observation
SIPP_panel = [SIPP_panel zeros(length(SIPP_panel),1)];
SIPP_panel(2:end,18) = diff(SIPP_panel(:,16));
SIPP_panel(1,18) = 1;
SIPP_panel(SIPP_panel(:,18)==0,:) = [];

%wage growth
SIPP_panel(2:end,12) = diff(log(SIPP_panel(:,6)));

%drop change in id
SIPP_panel(:,7) = order_index(SIPP_panel(:,7));
SIPP_panel(2:end,9) = diff(SIPP_panel(:,7));
SIPP_panel(:,9) = SIPP_panel(:,9)~=0; %make it a 1 indicator
SIPP_panel(1,9) = 1;
SIPP_panel(SIPP_panel(:,9)==1,:) = [];

jtj = SIPP_panel(SIPP_panel(:,8)==1,:);
otj = SIPP_panel(SIPP_panel(:,8)==0,:);

%regress on constant 
reg = ols(jtj(:,12),ones(length(jtj),1));
resid.jtj = reg.resid;

reg = ols(otj(:,12),ones(length(otj),1));
resid.otj = reg.resid;

within.variance_s = var(resid.otj);
between.variance_s = var(resid.jtj);

end