function variance = wv(SIPP_panel)
%computes moment for individual wage innovations

%% preparations

%compute spell number
SIPP_panel(:,7) = cumsum(SIPP_panel(:,11)); 

%keep only long enough observations
cut = 26;
index = count_obs(SIPP_panel(:,7));
delete = index>cut;
SIPP_panel(delete==0,:) = []; 


%recalculate spell and spell length
SIPP_panel(:,7) = order_index(SIPP_panel(:,7));
index = accumarray(SIPP_panel(:,7),1);
%% compute leads and lags

%create lag and leads of wage growth
LAG = NaN(length(SIPP_panel),13);
LEAD = NaN(length(SIPP_panel),13);

%compute lag wage growth
for l = 1:13
    st = l; %starting point
    for i = 1:length(SIPP_panel)-l
        LAG(st+i,l) = SIPP_panel(st+i-l,13);
    end
end 
%compute lead wage growth
for l = 1:13
    ed = l; %end point
    for i = 1:length(SIPP_panel)-ed
        LEAD(i,l) = SIPP_panel(i+l,13);
    end
end


%correct LAGs at beginning of observation period
correct = zeros(length(SIPP_panel),13);
for i = 1:13 %loop over column entries
    fcn = @(x){create_LAG(x,length(x),i)};
    correct(:,i) = accumarray_expand(ones(length(SIPP_panel),1),SIPP_panel(:,7),fcn);
end
LAG = correct.*LAG;


%correct leads at end of observation period
correct = zeros(length(SIPP_panel),13);
for i = 1:13 %loop over column entries
    fcn = @(x){create_LEAD(x,length(x),i)};
    correct(:,i) = accumarray_expand(ones(length(SIPP_panel),1),SIPP_panel(:,7),fcn);
end
LEAD = correct.*LEAD;

%delete lags and leads that are not available
index = isnan(LAG)+isnan(LEAD);
index = index>0;
index = sum(index,2);
LEAD(index>0,:) = [];
LAG(index>0,:) = [];
SIPP_panel(index>0,:) = [];
variance = SIPP_panel(:,13).*(sum(LAG+LEAD,2)+SIPP_panel(:,13));
variance = mean(variance);
end
