/* Please do not attemp to run this program without reading the accompanying documentation. */


clear

/*
File: extract_93.do
Date: August 11, 2003
Desc: This program extracts the 1992 data.
Note: See copyright notice at the end of this program.
*/

/* Acknowledgements

I am grateful to Jean Roth and others at the NBER for their efforts to make 
the data widely available. Many thanks also to Helen Connolly, Danielle Gao, 
Noelle (Bethney) Gundersen, John Schmitt, Jeffrey Sisson, Jeffrey Wenger and 
the SIPP Outreach Staff at the U.S. Census Bureau for helpful discussions 
about the SIPP data. Bradley Hardy provided valuable research assistance on 
this project.

The construction of this SIPP extract has been funded by a generous grant from 
the Rockefeller Foundation.

The *.do and *.dct files associated with this extract program that begin with the 
prefix "sip" were initially created by Jean Roth at the National Bureau of 
Economic Research, although they have been edited for use in this program. 
Complete details and all underlying data are available from the NBER 
(www.nber.org). Please report errors in those program to jroth@nber.org. 
Copyright 2003 shared by Jean Roth and the National Bureau of Economic Research.

The underlying Survey of Income and Program Participation data referenced here 
are in the public domain. The programs are distributed under the GNU GPL. 
See  of this file and http://www.gnu.org/licenses/ for details.

*/

/* USER NOTES

This program will read the 1993 SIPP panel into Stata format and label 
the variables and their values. The underlying data must be downloaded from 
the NBER (http://www.nber.org/data/sipp.html), or from the U.S. Census. 
The raw data will come in *.dat format. Downloading directions can 
be found at the CEPR websited (http:///www.cepr.net/data/sipp_extract.html). 

CEPR's extract programs are meant to substitute for the NBER *.dct and 
*.do files so these do not need to be downloaded from the NBER. In particular, 
the CEPR programs have changed the format of the variables necessary 
to generate the unique id from numeric into string in order to 
concatenate them correctly.

Prior to running this program, the user should create two directories and 
suggested names are below. If you choose not to create directories with the 
following names, you must change the directories referred to below as well as 
make changes in every *.do and *.dct file associated with this extract program 
to reflect your preferred directory structure. This process will be much 
less painful if you use the directory names suggested below.

Save all *.do and *.dct files (from CEPR) in the following directory:
c:\_files\programs\sipp\extract\sipp93\

Save all unzipped *.dat files (from the NBER or the U.S. Census) in the 
following directory:
c:\_files\data\sipp\sipp93\

This program was written for Intercooled Stata Version 8.0. It is 
recommended that you have 1GB of ram memory. 

Please direct all questions to <datahelp@cepr.net>.

*/

	/* Windows vs. GNU/Linux */
global gnulin=1 /* set equal to zero for Windows */
	
	/* GNU/Linux */
if $gnulin==1 {
*If you run GNU/Linux, be sure to change $rootdir to match your root directory
global rootdir /Uni/Het Agents/Daten/SIPP/1993 Revise
global programs $rootdir/programs/
global log $rootdir/programs/
global dictdir $rootdir/programs/
global rawdata $rootdir/rawdata
global output $rootdir/rawdata
}

	/* Windows */
if $gnulin==0 {
/*If you run Windows, be sure to change $rootdir to match your root directory*/
global rootdir "f:Uni\Het Agents\Daten\SIPP\1993 NBER"
global programs "$rootdir\programs"
global log "$rootdir\programs"
global dictdir "$rootdir\programs"
global rawdata "$rootdir\rawdata"
global output "$rootdir\rawdata"
}

cd "/Uni/Het Agents/Daten/SIPP/1993 Revise/programs"

/* Longitudinal
The full longitudinal panel has more than 2,047 variables, which is the 
maximum allowed in Intercooled Stata. To get around this, I've divided
the longitudinal panel up into three smaller datasets.
*/

local i = 1
while `i'<4 {
	log using sip93fp`i'.log, replace

	*Macros for dictionary files and raw SIPP data files
		
	
	do sip93fp`i'.do
	
	sort pp_id pp_entry pp_pnum
	egen id = concat(pp_id pp_entry pp_pnum)
	sort id

	save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93l`i'.dta", replace
	log close
	clear
	local i=`i'+1
}	


* Core and Topical Module Files */

*longitudional files
local i=1
while `i'<10 {
log using sip93w`i'.log, replace 
do sip93w`i'.do
rename refmth srefmon
sort suid entry pnum
egen id = concat(suid entry pnum)	
sort id rot
save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93w`i'.dta", replace
log close
clear
local i=`i'+1
}

*topical module files
local i=1
while `i'<10 {
log using sip93t`i'.log, replace 
do sip93t`i'.do
rename id suid
rename rotation rot
sort suid entry pnum
egen id = concat(suid entry pnum)
sort id rot
save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93t`i'.dta", replace
log close
clear
local i=`i'+1

if `i'==6 | `i'==9 {
log using sip93t`i'a.log, replace 
do sip93t`i'a.do
rename id suid
rename rotation rot
sort suid entry pnum
egen id = concat(suid entry pnum)
save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93t`i'a.dta", replace
log close
log using sip93t`i'b.log, replace
do sip93t`i'b.do 
rename id suid
rename rotation rot
sort suid entry pnum
egen id = concat(suid entry pnum)
save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93t`i'b.dta", replace
log close
clear
local i=`i'+1
}
}

* Job ID Revised files
log using sip93jid.log,replace

/*Macros for dictionary files and raw SIPP data files*/
				
do sip93jid.do

sort suid entry pnum
egen id = concat(suid entry pnum)
sort id

save "/Uni/Het Agents/Daten/SIPP/1993 Revise/rawdata/sipp93jid.dta", replace
log close
clear
